package com.tiptimes.service;

import com.tiptimes.model.*;
import com.tiptimes.model.QuestionnaireDTO.*;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.List;
import java.util.Map;

public interface QuestionnaireService {



  /**
   * 根据上报人和问卷id查询上报记录id
   * @param questionnaireUuid 问卷id
   * @param createId 上报人唯一标识
   * @return
   */
  Long selectRecordId(Long questionnaireUuid,String createId);

  /**
   * 根据上报人和问卷id查询上报记录id
   * @param questionnaire 上报人唯一标识
   * @return
   */
  Long selectRecordIds(Questionnaire questionnaire);

  /**
   * 添加上报记录数据
   * @param record 上报记录
   * @return
   */
  Long insertRecord(Record record);

  /**
   * 根据上报记录id删除原上报数据
   * @param recordId 上报记录id
   * @return
   */
  Integer delAnswer(Long recordId);

  /**
   * 新增新的上报数据
   * @param answerList
   * @param recordId
   * @return
   */
  Integer insertAnswer(List<Answer> answerList,Long recordId);

  /**
   * 修改数据上报状态
   * @param record
   * @return
   */
  Integer updateRecord(Record record);

  /**
   * 通过记录id删除原有备注
   * @param recordId
   * @return
   */
  Integer delView(Long recordId,Long questionsId);

  /**
   * 添加新的备注
   * @param review
   * @return
   */
  Integer insertReview(List<Review> review,Long recordId);


  /**
   *根据记录id查询上报数据详情
   * @param recordId 记录id
   * @return
   */
  List<Answer> selectAnswerByRecordId(Long recordId);

  /**
   *根据记录id查询评审备注详情
   * @param recordId 记录id
   * @return
   */
  List<Review> selectReviewByRecordId(Long recordId);

  /**
   * 根据年份查询当前年份对应的问题id
   * @return
   */
  List<YearId> selectQnYearId(Integer qnYear);


  /**
   *根据记录id查询评审备注详情
   * @param recordId 记录id
   * @return
   */
  Record selectById(Long recordId);

  /**
   * 按条件查询上报记录
   * @param record 筛选条件
   * @return
   */
  List<Record> selectRecordList(Record record);

  //根据选项id查询文件对应id
  List<String> selectFileId(Long optionId,Long recordId);

  //统计众创空间的分数
  List<PerformanceSummary> selectPerformanceSummaryList(PerformanceSummary performanceSummary);

  List<PerformanceSummary> selectPerformanceSummaryListNew(PerformanceSummary performanceSummary);


  List<PerformanceSummaryDTO> selectPerformanceList(PerformanceSummary performanceSummary);


  void exportFullTimeWorkPerson(HttpServletRequest request, HttpServletResponse response, String index, String recordId);

  void exportPerformanceSummary(HttpServletRequest request, HttpServletResponse response);

  void exportPerformanceSummaryNew(HttpServletRequest request, HttpServletResponse response,Integer qnYear);

  Integer updateAnswerScore(Answer answer);

  Review selectOneReviewByRecordIdAndQuestionsId( Long recordId, Long questionsId);

  Integer updateOneReviewByRecordIdAndQuestionsId(Review review);

  Integer insertOneReview(Review review);

  Integer saveReview(List<Review> reviews) throws Exception;

  Map<String,Object> modifyRecordStatusByRecordId(Long recordId);

  Map<String,Object> generateTableTask();

  Map<String,Object> generateRecordTask();

  List<Record> AboutViewList(Record record);

  List<Record> CountYearId(Record record);

  List<Questionnaire> CountYearIdQuestion(Questionnaire questionnaire);

  List<Record> AboutViewListCopy(Record record);

  List<Options> queryArray(Options options);

  void exportFullTimeWorkPersonNew(HttpServletRequest request, HttpServletResponse response, String index, String recordId,Integer qnYear,String createId,
                                   Integer id1, Integer id2, Integer id3,
                                   Integer id9, Integer id10, Integer id11, Integer id12, Integer id13, Integer id14,
                                   Integer id16, Integer id17, Integer id18, Integer id19, Integer id20,
                                   Integer id21, Integer id22, Integer id23, Integer id24,
                                   Integer id25, Integer id26, Integer id27, Integer id28, Integer id29, Integer id30, Integer id31, Integer id32, Integer id33, Integer id34,
                                   Integer id35, Integer id36, Integer id37, Integer id38, Integer id39, Integer id40,Integer id41,Integer id42,Integer id43,Integer id44, Integer id45, Integer id46,Integer id47,Integer id48,Integer id49,Integer id50,Integer id51,
                                   Integer id52,Integer id53,Integer id54,Integer id55,Integer id56,
                                   Integer id57,Integer id58,Integer id59,
                                   Integer id60,
                                   Integer id62, Integer id63, Integer id64,
                                   Integer id65,Integer id66,Integer id67,
                                   Integer id68,Integer id69,Integer id70,Integer id71,
                                   Integer id72,Integer id73,Integer id74,
                                   Integer id75,Integer id76,
                                   Integer id77,Integer id78,Integer id79,Integer id80,Integer id81,
                                   Integer id82,Integer id83,Integer id84,Integer id85,Integer id86,
                                   Integer id87,Integer id88,Integer id89,Integer id90,Integer id91,Integer id92,
                                   Integer id93,Integer id94,Integer id95,Integer id96,
                                   Integer id97,Integer id98
                                   );

  /**
   * 根据年份查询表单
   * @param year 年份
   * @param createId 上报人id
   * @return  结果
   */
  List<FormOptionByGroup> getFormOptions(int year, String createId);

  /**
   * 查询上报记录
   * @param reportDto 上报数据
   */
  Map<String,Object> selectReport(ReportDto reportDto);

  /**
   * 单次提交审核
   * @param saveQuestionByGroup 单次提交
   * @return 结果
   */

  boolean saveQuestionByGroup(SaveQuestionByGroup saveQuestionByGroup);


  /**
   * 校验是否存在审批数据
   * @param recordId 上报ID
   * @return 存在 true
   */
  boolean isEmptyReview(Long recordId);


  /**
   * 根据UUID查询问题组
   * @param questionnaireUId
   * @return
   */
  List<QuestionGroupDTO> getQuestionGroups (Long questionnaireUId);




  /**
   * 根据上报id和创建ID查询上报信息
   * @param questionnaireUuid
   * @param createId
   * @return
   */
  Record getRecord(Long questionnaireUuid,String createId);


  /**
   * 审核表单回显
   * @param uid 表单id
   * @param createId 创建人
   * @param year 年份
   * @return 结果
   */
  List<SaveQuestionDTO> queryReview(Long uid, String createId, int year);


  /**
   * 审核上报
   * @param uid 问卷id
   * @param createId 创建人
   * @param year 年份
   * @param status 状态
   * @return 结果
   */
  boolean adminSubmit(Long uid, String createId, int year ,int status);
}
