package com.tiptimes.service.impl;

import com.alibaba.excel.EasyExcel;
import com.alibaba.excel.ExcelWriter;
import com.alibaba.excel.write.metadata.WriteSheet;
import com.alibaba.excel.write.metadata.style.WriteCellStyle;
import com.alibaba.excel.write.metadata.style.WriteFont;
import com.alibaba.excel.write.style.HorizontalCellStyleStrategy;
import com.alibaba.excel.write.style.column.SimpleColumnWidthStyleStrategy;
import com.tiptimes.ctrl.ExcelFillCellMergeStrategy;
import com.tiptimes.ctrl.QuestionEnum;
import com.tiptimes.ctrl.QuestionnaireVo;
import com.tiptimes.dao.QuestionnaireDao;
import com.tiptimes.model.*;
import com.tiptimes.model.QuestionnaireDTO.*;
import com.tiptimes.model.exportDTO.*;
import com.tiptimes.service.QuestionnaireService;
import org.apache.commons.lang.StringUtils;
import org.apache.poi.ss.usermodel.HorizontalAlignment;
import org.apache.poi.ss.usermodel.IndexedColors;
import org.apache.poi.ss.usermodel.VerticalAlignment;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.math.BigDecimal;
import java.util.*;
import java.util.stream.Collectors;

import static org.apache.commons.lang.math.NumberUtils.max;

@Service
public class QuestionnaireServiceImpl implements QuestionnaireService {

    @Autowired
    private QuestionnaireDao questionnaireDao;

    /**
     * 根据上报人和问卷id查询上报记录id
     *
     * @param questionnaireUuid 问卷id
     * @param createId          上报人唯一标识
     * @return
     */
    @Override
    @Transactional(readOnly = true)
    public Long selectRecordId(Long questionnaireUuid, String createId) {
        return questionnaireDao.selectRecordId(questionnaireUuid, createId);
    }

    /**
     * 根据上报人和问卷id查询上报记录id
     * <p>
     * //     * @param questionnaireUuid 问卷id
     *
     * @param questionnaire 上报人唯一标识
     * @return
     */
    @Override
    @Transactional(readOnly = true)
    public Long selectRecordIds(Questionnaire questionnaire) {
        return questionnaireDao.selectRecordIds(questionnaire);
    }

    /**
     * 添加上报记录
     *
     * @param record 上报记录
     * @return
     */
    @Override
    @Transactional
    public Long insertRecord(Record record) {
        return questionnaireDao.insertRecord(record);
    }

    /**
     * 根据上报记录id删除原上报数据
     *
     * @param recordId 上报记录id
     * @return
     */
    @Override
    @Transactional
    public Integer delAnswer(Long recordId) {
        return questionnaireDao.delAnswer(recordId);
    }

    /**
     * 添加上报数据
     *
     * @param answerList
     * @param recordId
     * @return
     */
    @Override
    @Transactional
    public Integer insertAnswer(List<Answer> answerList, Long recordId) {
        return questionnaireDao.insertAnswer(answerList, recordId);
    }

    /**
     * 修改上报记录
     *
     * @param record
     * @return
     */
    @Override
    @Transactional
    public Integer updateRecord(Record record) {
        //先去查询 t_review  表里的审批状态是否全部为通过，都是通过的状态，更新列表的审批状态为已审批=3
        if (record.getReviews() != null) {
            List<Review> reviewList = questionnaireDao.selectAnswerByStatus(record.getReviews().get(0).getRecordId());
            reviewList.removeAll(Collections.singleton(null));
            //查询审批页面问题通过的个数
            List<Integer> reviews = questionnaireDao.selectAnswerByQuestion(record.getReviews().get(0).getRecordId());
            //问题个数
            List<Integer> list = Arrays.asList(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27);

            if (reviewList != null) {
                //查询结果为一条数据，并且状态都是通过，更新列表状态为3
                if (reviewList.size() == 1 && reviewList.get(0).getApprovalStatus() == 1 && reviews.containsAll(list)
                        && list.containsAll(reviews)) {
                    record.setProcessStatus(3);
                } else if (reviewList.size() > 1) {
                    //既有通过和驳回，更新列表状态为2-驳回
                    record.setProcessStatus(2);
                } else {
                    //列表状态为待审批
                    record.setProcessStatus(record.getProcessStatus());
                }
            }
        }

        return questionnaireDao.updateRecord(record);
    }

    /**
     * 通过记录id删除原有备注
     *
     * @param recordId
     * @return
     */
    @Override
    @Transactional
    public Integer delView(Long recordId, Long questionsId) {
        return questionnaireDao.delView(recordId, questionsId);
    }

    /**
     * 添加新的备注
     *
     * @param review
     * @return
     */
    @Override
    @Transactional
    public Integer insertReview(List<Review> review, Long recordId) {
        return questionnaireDao.insertReview(review, recordId);
    }

    /**
     * 通过记录id删除原有备注
     *
     * @param recordId
     * @return
     */
    @Override
    public List<Answer> selectAnswerByRecordId(Long recordId) {
        return questionnaireDao.selectAnswerByRecordId(recordId);
    }

    /**
     * 根据记录id查询评审备注详情
     *
     * @param recordId 记录id
     * @return
     */
    @Override
    public List<Review> selectReviewByRecordId(Long recordId) {
        return questionnaireDao.selectReviewByRecordId(recordId);
    }

    @Override
    public List<YearId> selectQnYearId(Integer qnYear) {
        return questionnaireDao.selectQnYearId(qnYear);
    }


    @Override
    public Record selectById(Long recordId) {
        return questionnaireDao.selectById(recordId);
    }

    /**
     * 按条件查询上报记录
     *
     * @param record 筛选条件
     * @return
     */
    @Override
    public List<Record> selectRecordList(Record record) {
        return questionnaireDao.selectRecordList(record);
    }

    @Override
    public List<String> selectFileId(Long optionId, Long recordId) {
        return questionnaireDao.selectFileId(optionId, recordId);
    }

    @Override
    public List<PerformanceSummary> selectPerformanceSummaryList(PerformanceSummary performanceSummary) {
        return questionnaireDao.selectPerformanceSummaryList(performanceSummary);
    }

    @Override
    public List<PerformanceSummary> selectPerformanceSummaryListNew(PerformanceSummary performanceSummary) {
        return questionnaireDao.selectPerformanceSummaryListNew(performanceSummary);
    }

    @Override
    public List<PerformanceSummaryDTO> selectPerformanceList(PerformanceSummary performanceSummary) {
        return questionnaireDao.selectPerformanceList(performanceSummary);
    }

    /**
     * 2022年10月新增加功能问卷管理-审批页面根据基础指标、引导指标和奖励指标导出所有空间的数据
     *
     * @param request
     * @param response
     * @param index    区分指标
     * @param recordId 上报记录id
     */
    @Override
    public void exportFullTimeWorkPerson(HttpServletRequest request, HttpServletResponse response, String index,
                                         String recordId) {
        try {
            WriteCellStyle headWriteCellStyle = new WriteCellStyle();
            //设置背景颜色
            headWriteCellStyle.setFillForegroundColor(IndexedColors.GREY_25_PERCENT.getIndex());
            //设置头字体
            WriteFont headWriteFont = new WriteFont();
            headWriteFont.setFontHeightInPoints((short) 10);
            headWriteFont.setBold(true);
            headWriteCellStyle.setWriteFont(headWriteFont);
            //设置头居中
            headWriteCellStyle.setHorizontalAlignment(HorizontalAlignment.CENTER);
            //内容策略
            WriteCellStyle contentWriteCellStyle = new WriteCellStyle();
            //设置 自动换行
            contentWriteCellStyle.setWrapped(true);
            //设置 垂直对齐
            contentWriteCellStyle.setVerticalAlignment(VerticalAlignment.CENTER);
            //设置 水平居中
            contentWriteCellStyle.setHorizontalAlignment(HorizontalAlignment.CENTER);
            // 这个策略是 头是头的样式 内容是内容的样式
            HorizontalCellStyleStrategy horizontalCellStyleStrategy =
                    new HorizontalCellStyleStrategy(headWriteCellStyle, contentWriteCellStyle);

            response.setContentType("application/vnd.ms-excel;charset=UTF-8");
            response.setCharacterEncoding("UTF-8");

            //需要合并的列
            int[] mergeColumnIndex = {1};
            // 从第二行后开始合并
            int mergeRowIndex = 1;

            switch (index) {
                case "1":
                    //导出文件名称
                    String fileName_a = "基础指标一";
                    response.setHeader("Content-disposition", "attachment;filename=" +
                            new String((fileName_a).getBytes("gb2312"),
                                    "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<SiteCondition> siteConditionList = questionnaireDao.selectSiteConditionList();
                    if (siteConditionList != null) {
                        for (int i = 0; i < siteConditionList.size(); i++) {
                            //excel生成序号
                            siteConditionList.get(i).setIndex(i + 1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(), SiteCondition.class)
                                .sheet("众创空间场地情况与是否租赁场地").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .doWrite(siteConditionList);
                        response.flushBuffer();
                    }
                    break;
                case "2":
                    //导出文件名称
                    String fileName_b = "基础指标二";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_b).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<FullTimeWorkPerson> fullTimeWorkPersonList = questionnaireDao.selectFullTimeWorkPersonList(recordId);
                    if (fullTimeWorkPersonList != null) {
                        for (int i = 0; i < fullTimeWorkPersonList.size(); i++) {
                            //excel生成序号
                            fullTimeWorkPersonList.get(i).setIndex(i + 1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(), FullTimeWorkPerson.class).sheet("众创空间场地情况").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .doWrite(fullTimeWorkPersonList);
                        response.flushBuffer();
                    }
                    break;
                case "3":
                    //导出文件名称
                    String fileName_c = "基础指标三";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_c).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<IncubatedEnterprises> incubatedEnterprisesList = questionnaireDao.selectIncubatedEnterprisesList();
                    if (incubatedEnterprisesList != null) {
                        for (int i = 0; i < incubatedEnterprisesList.size(); i++) {
                            //excel生成序号
                            incubatedEnterprisesList.get(i).setIndex(i + 1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(), IncubatedEnterprises.class).sheet("入孵企业情况").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .doWrite(incubatedEnterprisesList);
                        response.flushBuffer();
                    }
                    break;
                case "4":
                    //导出文件名称
                    String fileName_d = "基础指标四";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_d).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<EmploymentSituation> employmentSituationList = questionnaireDao.selectEmploymentSituationList();
                    if (employmentSituationList != null) {
                        for (int i = 0; i < employmentSituationList.size(); i++) {
                            //excel生成序号
                            employmentSituationList.get(i).setIndex(i + 1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(), EmploymentSituation.class).sheet("新增就业情况").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .doWrite(employmentSituationList);
                        response.flushBuffer();
                    }
                    break;
                case "5":
                    //导出文件名称
                    String fileName_e = "基础指标五";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_e).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<EntrepreneurshipCourses> entrepreneurshipCoursesList = questionnaireDao.selectEntrepreneurshipCoursesList();
                    if (entrepreneurshipCoursesList != null) {
                        for (int i = 0; i < entrepreneurshipCoursesList.size(); i++) {
                            //excel生成序号
                            entrepreneurshipCoursesList.get(i).setIndex(i + 1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(), EntrepreneurshipCourses.class).sheet("开设创新创业课程情况").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .doWrite(entrepreneurshipCoursesList);
                        response.flushBuffer();
                    }
                    break;
                case "6":
                    //导出文件名称
                    String fileName_f = "基础指标六";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_f).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<SigningMentors> signingMentorsList = questionnaireDao.selectSigningMentorsList();
                    if (signingMentorsList != null) {
                        for (int i = 0; i < signingMentorsList.size(); i++) {
                            //excel生成序号
                            signingMentorsList.get(i).setIndex(i + 1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(), SigningMentors.class).sheet("签约创业导师情况").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .doWrite(signingMentorsList);
                        response.flushBuffer();
                    }
                    break;
                case "7":
                    //导出文件名称
                    String fileName_g = "基础指标七";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_g).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<OrganizationActivity> organizationActivityList = questionnaireDao.selectOrganizationActivityList();
                    if (organizationActivityList != null) {
                        for (int i = 0; i < organizationActivityList.size(); i++) {
                            //excel生成序号
                            organizationActivityList.get(i).setIndex(i + 1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(), OrganizationActivity.class).sheet("组织双创活动情况").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .doWrite(organizationActivityList);
                        response.flushBuffer();
                    }
                    break;
                case "8":
                    //导出文件名称
                    String fileName_h = "基础指标八";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_h).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<CompetingSituation> competingSituationList = questionnaireDao.selectCompetingSituationList();
                    if (competingSituationList != null) {
                        for (int i = 0; i < competingSituationList.size(); i++) {
                            //excel生成序号
                            competingSituationList.get(i).setIndex(i + 1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(), CompetingSituation.class).sheet("参赛情况").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .doWrite(competingSituationList);
                        response.flushBuffer();
                    }
                    break;
                case "9":
                    //导出文件名称
                    String fileName_j = "基础指标九";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_j).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<EntrepreneurshipFunding> entrepreneurshipFundingList = questionnaireDao.selectEntrepreneurshipFundingList();
                    if (entrepreneurshipFundingList != null) {
                        for (int i = 0; i < entrepreneurshipFundingList.size(); i++) {
                            //excel生成序号
                            entrepreneurshipFundingList.get(i).setIndex(i + 1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(), EntrepreneurshipFunding.class).sheet("创新创业工作经费").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .doWrite(entrepreneurshipFundingList);
                        response.flushBuffer();
                    }
                    break;
                case "10":
                    //引导指标1 --基础指标1
                    //导出文件名称
                    String fileName_aa = "引导指标一";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_aa).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<SiteCondition> leadingIndicatorOneList = questionnaireDao.selectSiteConditionList();
                    if (leadingIndicatorOneList != null) {
                        for (int i = 0; i < leadingIndicatorOneList.size(); i++) {
                            //excel生成序号
                            leadingIndicatorOneList.get(i).setIndex(i + 1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(), SiteCondition.class).sheet("引导指标一").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .doWrite(leadingIndicatorOneList);
                        response.flushBuffer();
                    }
                    break;
                case "11":
                    //引导指标2 --基础指标1
                    //导出文件名称
                    String fileName_bb = "引导指标二";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_bb).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<SiteCondition> leadingIndicatorTwoList = questionnaireDao.selectSiteConditionList();
                    if (leadingIndicatorTwoList != null) {
                        for (int i = 0; i < leadingIndicatorTwoList.size(); i++) {
                            //excel生成序号
                            leadingIndicatorTwoList.get(i).setIndex(i + 1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(), SiteCondition.class).sheet("引导指标二").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .doWrite(leadingIndicatorTwoList);
                        response.flushBuffer();
                    }
                    break;
                case "12":
                    //引导指标3 --基础指标3
                    //导出文件名称
                    String fileName_cc = "引导指标三";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_cc).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<IncubatedEnterprises> leadingIndicatorThreeList = questionnaireDao.selectIncubatedEnterprisesList();
                    if (leadingIndicatorThreeList != null) {
                        for (int i = 0; i < leadingIndicatorThreeList.size(); i++) {
                            //excel生成序号
                            leadingIndicatorThreeList.get(i).setIndex(i + 1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(), IncubatedEnterprises.class).sheet("引导指标三").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .doWrite(leadingIndicatorThreeList);
                        response.flushBuffer();
                    }
                    break;
                case "13":
                    //引导指标4 --基础指标3
                    //导出文件名称
                    String fileName_dd = "引导指标四";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_dd).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<IncubatedEnterprises> leadingIndicatorFoureList = questionnaireDao.selectIncubatedEnterprisesList();
                    if (leadingIndicatorFoureList != null) {
                        for (int i = 0; i < leadingIndicatorFoureList.size(); i++) {
                            //excel生成序号
                            leadingIndicatorFoureList.get(i).setIndex(i + 1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(), IncubatedEnterprises.class).sheet("引导指标四").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .doWrite(leadingIndicatorFoureList);
                        response.flushBuffer();
                    }
                    break;
                case "14":
                    //引导指标5 --基础指标4
                    //导出文件名称
                    String fileName_ee = "引导指标五";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_ee).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<EmploymentSituation> employmentSituationList1 = questionnaireDao.selectEmploymentSituationList();
                    if (employmentSituationList1 != null) {
                        for (int i = 0; i < employmentSituationList1.size(); i++) {
                            //excel生成序号
                            employmentSituationList1.get(i).setIndex(i + 1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(), EmploymentSituation.class).sheet("新增就业情况").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .doWrite(employmentSituationList1);
                        response.flushBuffer();
                    }
                    break;
                case "15":
                    //引导指标6
                    //导出文件名称
                    String fileName_k = "引导指标六";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_k).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    response.setContentType("application/vnd.openxmlformats-officedocument.spreadsheetml.sheet");
                    ExcelWriter excelWriter = EasyExcel.write(response.getOutputStream()).build();
                    //查询数据
                    List<EntrepreneurshipCourses> entrepreneurshipCoursesList5 = questionnaireDao.selectEntrepreneurshipCoursesList();
                    if (entrepreneurshipCoursesList5 != null) {
                        for (int i = 0; i < entrepreneurshipCoursesList5.size(); i++) {
                            //excel生成序号
                            entrepreneurshipCoursesList5.get(i).setIndex(i + 1);
                        }
                        WriteSheet writeSheet1 = EasyExcel.writerSheet(0, "开设创新创业课程情况")
                                .head(EntrepreneurshipCourses.class)
                                .registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .build();
                        excelWriter.write(entrepreneurshipCoursesList5, writeSheet1);
                    }
                    //查询数据
                    List<EntrepreneurshipProject> entrepreneurshipProjectList = questionnaireDao.selectEntrepreneurshipProjectList();
                    if (entrepreneurshipProjectList != null) {
                        for (int i = 0; i < entrepreneurshipProjectList.size(); i++) {
                            //excel生成序号
                            entrepreneurshipProjectList.get(i).setIndex(i + 1);
                        }
                        //生成excel
                        WriteSheet writeSheet0 = EasyExcel.writerSheet(1, "申报成功高校众创空间联盟发布的创新创业研究课题信息")
                                .head(EntrepreneurshipProject.class)
                                .registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .build();
                        excelWriter.write(entrepreneurshipProjectList, writeSheet0);
                    }
                    excelWriter.finish();
                    response.flushBuffer();
                    break;
                case "16":
                    //引导指标7 --基础指标6
                    //导出文件名称
                    String fileName_ff = "引导指标七";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_ff).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<SigningMentors> leadingIndicatorSixList = questionnaireDao.selectSigningMentorsList();
                    if (leadingIndicatorSixList != null) {
                        for (int i = 0; i < leadingIndicatorSixList.size(); i++) {
                            //excel生成序号
                            leadingIndicatorSixList.get(i).setIndex(i + 1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(), SigningMentors.class).sheet("引导指标七").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .doWrite(leadingIndicatorSixList);
                        response.flushBuffer();
                    }
                    break;
                case "17":
                    //引导指标8 --基础指标7
                    //导出文件名称
                    String fileName_gg = "引导指标八";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_gg).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<OrganizationActivity> leadingIndicatorSevenList = questionnaireDao.selectOrganizationActivityList();
                    if (leadingIndicatorSevenList != null) {
                        for (int i = 0; i < leadingIndicatorSevenList.size(); i++) {
                            //excel生成序号
                            leadingIndicatorSevenList.get(i).setIndex(i + 1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(), OrganizationActivity.class).sheet("引导指标八").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .doWrite(leadingIndicatorSevenList);
                        response.flushBuffer();
                    }
                    break;
                case "18":
                    //引导指标9
                    //导出文件名称
                    String fileName_l = "引导指标九";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_l).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<EnterprisestAmount> enterprisestAmountList = questionnaireDao.selecEnterprisestAmountList();
                    if (enterprisestAmountList != null) {
                        for (int i = 0; i < enterprisestAmountList.size(); i++) {
                            //excel生成序号
                            enterprisestAmountList.get(i).setIndex(i + 1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(), EnterprisestAmount.class).sheet("在孵企业销售收入或累计合同额情况").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .doWrite(enterprisestAmountList);
                        response.flushBuffer();
                    }
                    break;
                case "19":
                    //引导指标10
                    //导出文件名称
                    String fileName_z = "引导指标十";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_z).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<EvaluationBorrowing> evaluationBorrowingList = questionnaireDao.selectEvaluationBorrowingList();
                    if (evaluationBorrowingList != null) {
                        for (int i = 0; i < evaluationBorrowingList.size(); i++) {
                            //excel生成序号
                            evaluationBorrowingList.get(i).setIndex(i + 1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(), EvaluationBorrowing.class).sheet("本评估周期实现股权或债权融资情况").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .doWrite(evaluationBorrowingList);
                        response.flushBuffer();
                    }
                    break;
                case "20":
                    //引导指标11
                    //导出文件名称
                    String fileName_x = "引导指标十一";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_x).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<InnovationWeek> innovationWeekList = questionnaireDao.selectInnovationWeekList();
                    if (innovationWeekList != null) {
                        for (int i = 0; i < innovationWeekList.size(); i++) {
                            //excel生成序号
                            innovationWeekList.get(i).setIndex(i + 1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(), InnovationWeek.class).sheet("主办或承办市级及以上级别路演、双创周活动").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .doWrite(innovationWeekList);
                        response.flushBuffer();
                    }
                    break;
                case "21":
                    //引导指标12
                    //导出文件名称
                    String fileName_v = "引导指标十二";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_v).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<CollegeSituation> collegeSituationList = questionnaireDao.selectCollegeSituationList();
                    if (collegeSituationList != null) {
                        for (int i = 0; i < collegeSituationList.size(); i++) {
                            //excel生成序号
                            collegeSituationList.get(i).setIndex(i + 1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(), CollegeSituation.class).sheet("在孵企业在OTC高校板挂牌情况").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .doWrite(collegeSituationList);
                        response.flushBuffer();
                    }
                    break;
                case "22":
                    //引导指标13
                    //导出文件名称
                    String fileName_o = "引导指标十三";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_o).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<EnterprisesIntellectual> enterprisesIntellectualList = questionnaireDao.selectEnterprisesIntellectualList();
                    if (enterprisesIntellectualList != null) {
                        for (int i = 0; i < enterprisesIntellectualList.size(); i++) {
                            //excel生成序号
                            enterprisesIntellectualList.get(i).setIndex(i + 1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(), EnterprisesIntellectual.class).sheet("在孵企业新增知识产权").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .doWrite(enterprisesIntellectualList);
                        response.flushBuffer();
                    }
                    break;
                case "23":
                    //奖励指标1
                    //导出文件名称
                    String fileName_p = "奖励指标一";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_p).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<NationalCompetitionAwards> nationalCompetitionAwardsList = questionnaireDao.selectNationalCompetitionAwardsList();
                    if (nationalCompetitionAwardsList != null) {
                        for (int i = 0; i < nationalCompetitionAwardsList.size(); i++) {
                            //excel生成序号
                            nationalCompetitionAwardsList.get(i).setIndex(i + 1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(), NationalCompetitionAwards.class).sheet("获得“互联网+”大赛全国赛事奖项情况").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .doWrite(nationalCompetitionAwardsList);
                        response.flushBuffer();
                    }
                    break;
                case "24":
                    //奖励指标2
                    //导出文件名称
                    String fileName_n = "奖励指标二";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_n).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<EducationCommission> educationCommissionList = questionnaireDao.selectEducationCommissionList();
                    if (educationCommissionList != null) {
                        for (int i = 0; i < educationCommissionList.size(); i++) {
                            //excel生成序号
                            educationCommissionList.get(i).setIndex(i + 1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(), EducationCommission.class).sheet("获得创客马拉松大赛及市教委组织的其他双创大赛奖项情况").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .doWrite(educationCommissionList);
                        response.flushBuffer();
                    }
                    break;
                case "25":
                    //奖励指标3
                    //导出文件名称
                    String fileName_m = "奖励指标三";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_m).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<EntrepreneurialProject> entrepreneurialProjectList = questionnaireDao.selectEntrepreneurialProjectList();
                    if (entrepreneurialProjectList != null) {
                        for (int i = 0; i < entrepreneurialProjectList.size(); i++) {
                            //excel生成序号
                            entrepreneurialProjectList.get(i).setIndex(i + 1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(), EntrepreneurialProject.class).sheet("入选天津市创业拔尖项目情况").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .doWrite(entrepreneurialProjectList);
                        response.flushBuffer();
                    }
                    break;
                case "26":
                    //奖励指标4-奖励指标5
                    //奖励指标3
                    //导出文件名称
                    String fileName_u = "奖励指标四";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_u).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<SpaceAndIncubation> spaceAndIncubationList = questionnaireDao.selectSpaceAndIncubationList();
                    if (spaceAndIncubationList != null) {
                        for (int i = 0; i < spaceAndIncubationList.size(); i++) {
                            //excel生成序号
                            spaceAndIncubationList.get(i).setIndex(i + 1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(), SpaceAndIncubation.class).sheet("是否为国家级备案众创空间").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .doWrite(spaceAndIncubationList);
                        response.flushBuffer();
                    }
                    break;
                default:
                    break;
            }

        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    @Override
    public void exportPerformanceSummary(HttpServletRequest request, HttpServletResponse response) {
        try {
            WriteCellStyle headWriteCellStyle = new WriteCellStyle();
            //设置背景颜色
            headWriteCellStyle.setFillForegroundColor(IndexedColors.GREY_25_PERCENT.getIndex());
            //设置头字体
            WriteFont headWriteFont = new WriteFont();
            headWriteFont.setFontHeightInPoints((short) 10);
            headWriteFont.setBold(true);
            headWriteCellStyle.setWriteFont(headWriteFont);
            //设置头居中
            headWriteCellStyle.setHorizontalAlignment(HorizontalAlignment.CENTER);
            //内容策略
            WriteCellStyle contentWriteCellStyle = new WriteCellStyle();
            contentWriteCellStyle.setWrapped(true);
            //设置 水平居中
            contentWriteCellStyle.setHorizontalAlignment(HorizontalAlignment.CENTER);
            HorizontalCellStyleStrategy horizontalCellStyleStrategy = new HorizontalCellStyleStrategy(headWriteCellStyle, contentWriteCellStyle);

            response.setContentType("application/vnd.ms-excel;charset=UTF-8");
            response.setCharacterEncoding("UTF-8");

            //导出文件名称
            String fileName_a = "绩效汇总表";
            response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_a).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");

            //查询引导指标和奖励指标数据
            List<PerformanceSummaryTotal> summaryList = questionnaireDao.queryGuideAndRewardIndexList();

            if (summaryList != null) {
                for (int i = 0; i < summaryList.size(); i++) {
                    //excel生成序号
                    summaryList.get(i).setIndex(i + 1);

                    //计算引导指标和奖励指标分数
                    float guideIndexScore = summaryList.get(i).getGuideIndexOne() + summaryList.get(i).getGuideIndexTwo() + summaryList.get(i).getGuideIndexThree()
                            + summaryList.get(i).getGuideIndexFour() + summaryList.get(i).getGuideIndexFive() + summaryList.get(i).getGuideIndexSix() + summaryList.get(i).getGuideIndexSeven()
                            + summaryList.get(i).getGuideIndexEight() + summaryList.get(i).getGuideIndexNine() + summaryList.get(i).getGuideIndexTen() + summaryList.get(i).getGuideIndexEleven()
                            + summaryList.get(i).getGuideIndexTwelve() + summaryList.get(i).getGuideIndexThirteen();
                    if (guideIndexScore >= 50.0) {
                        summaryList.get(i).setGuideIndexScore(50);
                    } else {
                        summaryList.get(i).setGuideIndexScore(guideIndexScore);
                    }

                    //计算奖励指标分数
                    float rewardIndexScore = summaryList.get(i).getRewardIndexOne() + summaryList.get(i).getRewardIndexTwo() + summaryList.get(i).getRewardIndexThree()
                            + summaryList.get(i).getRewardIndexFour() + summaryList.get(i).getRewardIndexFive();
                    if (rewardIndexScore >= 10.0) {
                        summaryList.get(i).setRewardIndexScore(10);
                    } else {
                        summaryList.get(i).setRewardIndexScore(rewardIndexScore);
                    }

                    //总分数
                    float totalScore = summaryList.get(i).getBasisIndexScore() + summaryList.get(i).getGuideIndexScore() + summaryList.get(i).getRewardIndexScore();
                    summaryList.get(i).setTotalScore(totalScore);
                }
                //生成excel
                EasyExcel.write(response.getOutputStream(), PerformanceSummaryTotal.class).sheet("绩效汇总表").
                        registerWriteHandler(horizontalCellStyleStrategy)
                        .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                        .doWrite(summaryList);
                response.flushBuffer();
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }


    @Override
    public void exportPerformanceSummaryNew(HttpServletRequest request, HttpServletResponse response, Integer qnYear) {
        try {
            WriteCellStyle headWriteCellStyle = new WriteCellStyle();
            //设置背景颜色
            headWriteCellStyle.setFillForegroundColor(IndexedColors.GREY_25_PERCENT.getIndex());
            //设置头字体
            WriteFont headWriteFont = new WriteFont();
            headWriteFont.setFontHeightInPoints((short) 10);
            headWriteFont.setBold(true);
            headWriteCellStyle.setWriteFont(headWriteFont);
            //设置头居中
            headWriteCellStyle.setHorizontalAlignment(HorizontalAlignment.CENTER);
            //内容策略
            WriteCellStyle contentWriteCellStyle = new WriteCellStyle();
            contentWriteCellStyle.setWrapped(true);
            //设置 水平居中
            contentWriteCellStyle.setHorizontalAlignment(HorizontalAlignment.CENTER);
            HorizontalCellStyleStrategy horizontalCellStyleStrategy = new HorizontalCellStyleStrategy(headWriteCellStyle, contentWriteCellStyle);

            response.setContentType("application/vnd.ms-excel;charset=UTF-8");
            response.setCharacterEncoding("UTF-8");

            //导出文件名称
            String fileName_a = "绩效汇总表";
            response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_a).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");

            List<PerformanceSummaryTotalDTO> list = new ArrayList<>();
            PerformanceSummary performanceSummary = new PerformanceSummary();
            performanceSummary.setQnYear(qnYear);
            List<PerformanceSummaryDTO> performanceSummaryList = selectPerformanceList(performanceSummary);
            int index =1;
            for (PerformanceSummaryDTO performanceSummaryDTO : performanceSummaryList) {

                PerformanceSummaryTotalDTO performanceSummaryTotalDTO = new PerformanceSummaryTotalDTO();
                performanceSummaryTotalDTO.setIndex(index);
                //引导指标分数
                performanceSummaryTotalDTO.setGuideIndexScore(performanceSummaryDTO.getGuideIndicators());
                //基础指标分数
                performanceSummaryTotalDTO.setBasisIndexScore(performanceSummaryDTO.getBasicIndicators());
                //奖励
                performanceSummaryTotalDTO.setRewardIndexScore(performanceSummaryDTO.getRewardIndicators());
                //总分
                BigDecimal total = BigDecimal.ZERO;
                total = total.add(performanceSummaryDTO.getBasicIndicators())
                        .add(performanceSummaryDTO.getRewardIndicators())
                        .add(performanceSummaryDTO.getGuideIndicators());
                performanceSummaryTotalDTO.setTotalScore(total);
                List<PerformanceSummaryDTO>  guideList =
                        questionnaireDao.queryGuideAndReward(qnYear, performanceSummaryDTO.getRecordId());
                List<PerformanceSummaryDTO> rewardList =
                        questionnaireDao.queryRewardReward(qnYear, performanceSummaryDTO.getRecordId());
                performanceSummaryTotalDTO.setGuideIndexOne(guideList.get(0).getGuideIndicators());
                performanceSummaryTotalDTO.setGuideIndexTwo(guideList.get(1).getGuideIndicators());
                performanceSummaryTotalDTO.setGuideIndexThree(guideList.get(2).getGuideIndicators());
                performanceSummaryTotalDTO.setGuideIndexFour(guideList.get(3).getGuideIndicators());
                performanceSummaryTotalDTO.setGuideIndexFive(guideList.get(4).getGuideIndicators());
                performanceSummaryTotalDTO.setGuideIndexSix(guideList.get(5).getGuideIndicators());
                performanceSummaryTotalDTO.setGuideIndexSeven(guideList.get(6).getGuideIndicators());
                performanceSummaryTotalDTO.setGuideIndexEight(guideList.get(7).getGuideIndicators());
                performanceSummaryTotalDTO.setGuideIndexNine(guideList.get(8).getGuideIndicators());
                performanceSummaryTotalDTO.setGuideIndexTen(guideList.get(9).getGuideIndicators());
                performanceSummaryTotalDTO.setGuideIndexEleven(guideList.get(10).getGuideIndicators());
                performanceSummaryTotalDTO.setGuideIndexTwelve(guideList.get(11).getGuideIndicators());
                performanceSummaryTotalDTO.setGuideIndexThirteen(guideList.get(12).getGuideIndicators());
                performanceSummaryTotalDTO.setRewardIndexOne(rewardList.get(0).getRewardIndicators());
                performanceSummaryTotalDTO.setRewardIndexTwo(rewardList.get(1).getRewardIndicators());
                performanceSummaryTotalDTO.setRewardIndexThree(rewardList.get(2).getRewardIndicators());
                performanceSummaryTotalDTO.setRewardIndexFour(rewardList.get(3).getRewardIndicators());
                performanceSummaryTotalDTO.setRewardIndexFive(rewardList.get(4).getRewardIndicators());
                performanceSummaryTotalDTO.setSpaceName(performanceSummaryDTO.getCreateBy());
                performanceSummaryTotalDTO.setBasisIndexOne("通过");
                performanceSummaryTotalDTO.setBasisIndexTwo("通过");
                performanceSummaryTotalDTO.setBasisIndexThree("通过");
                performanceSummaryTotalDTO.setBasisIndexFour("通过");
                performanceSummaryTotalDTO.setBasisIndexFive("通过");
                performanceSummaryTotalDTO.setBasisIndexSix("通过");
                performanceSummaryTotalDTO.setBasisIndexSeven("通过");
                performanceSummaryTotalDTO.setBasisIndexEight("通过");
                performanceSummaryTotalDTO.setBasisIndexNine("通过");
                index++;
                list.add(performanceSummaryTotalDTO);
            }
                //生成excel
                EasyExcel.write(response.getOutputStream(), PerformanceSummaryTotalDTO.class).sheet("绩效汇总表").
                        registerWriteHandler(horizontalCellStyleStrategy)
                        .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                        .doWrite(list);
                response.flushBuffer();

        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    @Override
    public Integer updateAnswerScore(Answer answer) {
        return questionnaireDao.updateAnswerScore(answer);
    }

    @Override
    public Review selectOneReviewByRecordIdAndQuestionsId(Long recordId, Long questionsId) {
        return questionnaireDao.selectOneReviewByRecordIdAndQuestionsId(recordId, questionsId);
    }

    @Override
    public Integer updateOneReviewByRecordIdAndQuestionsId(Review review) {
        return questionnaireDao.updateOneReviewByRecordIdAndQuestionsId(review);
    }

    @Override
    public Integer insertOneReview(Review review) {
        return questionnaireDao.insertOneReview(review);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public Integer saveReview(List<Review> reviews) throws Exception {
        //结果
        Integer result = 0;
        //遍历存在则更新，不存在则新增
        for (Review reviewItem : reviews) {
            if (questionnaireDao.selectOneReviewByRecordIdAndQuestionsId(reviewItem.getRecordId(), reviewItem.getQuestionsId()) == null) {
                //新增
                result += questionnaireDao.insertOneReview(reviewItem);
            } else {
                //更新
                result += questionnaireDao.updateOneReviewByRecordIdAndQuestionsId(reviewItem);
            }
        }
        if (reviews.size() == result) {
            return result;
        } else {
            throw new Exception();
        }
    }

    @Override
    public Map<String, Object> modifyRecordStatusByRecordId(Long recordId) {
        Map<String, Object> map = new HashMap<>();
        Record record = new Record();
        record.setId(recordId);
        List<Review> reviews = questionnaireDao.selectReviewListByRecordId(recordId);
        if (reviews.size() != 27) {
            //还未审核完 状态改为1待审核
            record.setProcessStatus(1);
            map.put("result", false);
            map.put("msg", "审核还未完成");
        } else {
            for (Review review : reviews) {
                if (review.getApprovalStatus() == 0) {
                    //有驳回 状态改为2 驳回
                    record.setProcessStatus(2);
                    map.put("result", true);
                    map.put("msg", "审核完成");
                    break;
                } else {
                    //全部审核结束并且状态未通过 改为3
                    record.setProcessStatus(3);
                    map.put("result", true);
                    map.put("msg", "审核完成");
                }
            }
        }
        int result = questionnaireDao.updateRecord(record);
        if (result > 0) {
            return map;
        } else {
            map.put("result", false);
            map.put("msg", "审核出错稍后再试！");
            return map;
        }
    }

    /**
     * 每年定时生成 问卷表、问题表和选线表的数据
     */
    @Override
    @Transactional
    public Map<String, Object> generateTableTask() {
        Map<String, Object> tblMap = new HashMap<>();

        QuestionnaireVo questionnaireVo = new QuestionnaireVo();
        // 获取系统当前年
        Calendar calendar = Calendar.getInstance();
        questionnaireVo.setQuestionnaireName(calendar.get(Calendar.YEAR) + "季度问卷");
        questionnaireVo.setStatus(1);
        questionnaireVo.setCreateTime(new Date());
        questionnaireVo.setCreateBy("姗姗老师");
        questionnaireVo.setQnYear(calendar.get(Calendar.YEAR));

        Long result = questionnaireDao.insertQuestionnaire(questionnaireVo);

        if (result > 0) {
            // 根据问卷表的年份查询最新入库的数据id
            int line = questionnaireDao.queryQuestionsId(calendar.get(Calendar.YEAR));

            // 插入问题表的数据t_questions,添加成功进入选项表的入库操作
            addQuestions(line);

            int res = addGroup(calendar.get(Calendar.YEAR));

            if (res == -1) {
                tblMap.put("code", 500);
                tblMap.put("result", false);
                tblMap.put("msg", "生成数据表失败！");
                return tblMap;
            }

            // 获取到t_questions标的id，根据每个问题的选项进行入库操作
            Integer qnYear = calendar.get(Calendar.YEAR);
            addOptions(qnYear);

            tblMap.put("code", 200);
            tblMap.put("result", true);
            tblMap.put("msg", "生成数据表成功！");
            return tblMap;
        } else {
            tblMap.put("code", 500);
            tblMap.put("result", false);
            tblMap.put("msg", "生成数据表失败！");
            return tblMap;
        }
    }

    /**
     * 每年定时生成问题表数据
     *
     * @param line
     * @return string
     */
    @Transactional
    public String addQuestions(Integer line) {
        int rtn = 0;
        List<String> questionList = Arrays.asList(QuestionEnum.BASIC_INFORMATION.getQuestionCode(),
                QuestionEnum.MAKER_SPACE.getQuestionCode(), QuestionEnum.LEASE_VENUE.getQuestionCode(),
                QuestionEnum.FULL_STATUS.getQuestionCode(), QuestionEnum.INCUBATED_ENTERPRISES.getQuestionCode(),
                QuestionEnum.JOB_CREATION.getQuestionCode(), QuestionEnum.ENTREPRENEURSHIP_COURSES.getQuestionCode(),
                QuestionEnum.ENTREPRENEURSHIP_MENTOR.getQuestionCode(),
                QuestionEnum.ENTREPRENEURSHIP_ACTIVITIES.getQuestionCode(),
                QuestionEnum.COMPETITION_SITUATION.getQuestionCode(),
                QuestionEnum.INNOVATION_ENTREPRENEURSHIP.getQuestionCode(),
                QuestionEnum.MAKER_INFORMATION.getQuestionCode(), QuestionEnum.INCUBATED_ENTERPRISE.getQuestionCode(),
                QuestionEnum.WEEK_ACTIVITIES.getQuestionCode(), QuestionEnum.LISTING_SITUATION.getQuestionCode(),
                QuestionEnum.PROPERTY_RIGHTS.getQuestionCode(), QuestionEnum.AWARD_SITUATION.getQuestionCode(),
                QuestionEnum.AWARDS_COMPETITION.getQuestionCode(), QuestionEnum.TOPSTATUS.getQuestionCode(),
                QuestionEnum.NATIONAL_RECORD.getQuestionCode(), QuestionEnum.NATIONAL_ENTREPRENEURSHIP.getQuestionCode(),
                QuestionEnum.OPERATION_SITUATION.getQuestionCode(), QuestionEnum.DEBT_FINANCING.getQuestionCode());
        for (String str : questionList) {
            // 保存问题表
            Questions question = new Questions();
            question.setQuestionnaireUuid(Long.valueOf(line));
            question.setQuestion(str);
            question.setStatus(1);
            question.setCreateTime(new Date());

            rtn = questionnaireDao.insertQuestions(question);
        }
        return String.valueOf(rtn);
    }

    /**
     * 组别表数据生成
     *
     * @param qnYear 年份
     * @return 结果
     */

    @Transactional
    public int addGroup(Integer qnYear) {

        try {
            // 根据问卷表的年份查询最新入库的数据id
            int questionnaireId = questionnaireDao.queryQuestionsId(qnYear);
            // 获取去年的分组数据
            List<Group> groups = questionnaireDao.selectGroupByYear(qnYear - 1);
            // 新数据
            List<Group> newGroups = new ArrayList<>();
            // 循环去年数据
            for (Group group : groups) {
                String[] split = group.getQuestionId().split(",");
                StringBuilder ids = new StringBuilder();
                Group newGroup = new Group();

                for (String s : split) {
                    Questions question = questionnaireDao.queryQuestionsById(Integer.parseInt(s));
                    int id = questionnaireDao.queryQuestionsByTitle(question.getQuestion(), questionnaireId);
                    ids.append(id).append(",");
                }

                newGroup.setGroupTitle(group.getGroupTitle());
                newGroup.setQnYear(qnYear);
                newGroup.setGroupType(group.getGroupType());
                newGroup.setQuestionId(ids.substring(0, ids.toString().length() - 1));
                newGroup.setQuestionnaireId(questionnaireId);
                newGroup.setRelevance(group.getRelevance());
                newGroup.setMaxPoint(group.getMaxPoint());
                newGroups.add(newGroup);
            }

            return questionnaireDao.addQuestionsList(newGroups);

        } catch (Exception e) {
            return -1;
        }
    }


    /**
     * 每年定时生成选项表数据
     *
     * @param qnYear
     * @return string
     */
    @Transactional
    public String addOptions(Integer qnYear) {
        int rtn = 0;
        try {
            // 获取当前年份的问题集合
            List<Questions> questionsList = questionnaireDao.queryQuestionsList(qnYear);
            if (questionsList != null) {
                for (Questions questions : questionsList) {
                    if (questions.getQuestion().equals(QuestionEnum.BASIC_INFORMATION.getQuestionCode())) {
                        // 基本信息
                        List<String> optionsList = Arrays.asList(QuestionEnum.SPACE_NAME.getQuestionCode(),
                                QuestionEnum.AFFILIATED_UNIVERSITY.getQuestionCode(),
                                QuestionEnum.PERSON_NAME.getQuestionCode(),
                                QuestionEnum.CONTACT_NUMBER.getQuestionCode());
                        // 调取保存方法
                        insertOptions(questions.getId(), optionsList);
                    } else if (questions.getQuestion().equals(QuestionEnum.MAKER_SPACE.getQuestionCode())) {
                        // 众创空间场地情况
                        List<String> optionsList = Arrays.asList(QuestionEnum.SPACE_INNOVATION.getQuestionCode(),
                                QuestionEnum.SPACE_NUMBER.getQuestionCode());
                        // 调取保存方法
                        insertOptions(questions.getId(), optionsList);
                    } else if (questions.getQuestion().equals(QuestionEnum.LEASE_VENUE.getQuestionCode())) {
                        // 是否租赁场地
                        List<String> optionsList = Arrays.asList(QuestionEnum.IS_LEASE_VENUE.getQuestionCode(),
                                QuestionEnum.LIVE_PHOTO.getQuestionCode());
                        // 调取保存方法
                        insertOptions(questions.getId(), optionsList);
                    } else if (questions.getQuestion().equals(QuestionEnum.FULL_STATUS.getQuestionCode())) {
                        // 众创空间配备专职工作人员情况
                        List<String> optionsList = Arrays.asList(QuestionEnum.FULL_STATUS_NAME.getQuestionCode(),
                                QuestionEnum.FULL_STATUS_OFFICE.getQuestionCode(),
                                QuestionEnum.FULL_STATUS_DEPARTMENT.getQuestionCode(),
                                QuestionEnum.FULL_STATUS_POSITION.getQuestionCode(),
                                QuestionEnum.FULL_STATUS_PHONE.getQuestionCode(),
                                QuestionEnum.FULL_STATUS_JOB.getQuestionCode());
                        // 调取保存方法
                        insertOptions(questions.getId(), optionsList);
                    } else if (questions.getQuestion().equals(QuestionEnum.OPERATION_SITUATION.getQuestionCode())) {
                        // 关于众创空间运营情况的说明
                        List<String> optionsList = Arrays.asList(QuestionEnum.FULL_STATUS_DESCRIPTION.getQuestionCode());
                        // 调取保存方法
                        insertOptions(questions.getId(), optionsList);
                    } else if (questions.getQuestion().equals(QuestionEnum.INCUBATED_ENTERPRISES.getQuestionCode())) {
                        // 入孵企业情况
                        List<String> optionsList = Arrays.asList(QuestionEnum.ENTERPRISES_NAME.getQuestionCode(),
                                QuestionEnum.ENTERPRISES_PROF.getQuestionCode(),
                                QuestionEnum.ENTERPRISES_EQUITY.getQuestionCode(),
                                QuestionEnum.ENTERPRISES_INCUBATION.getQuestionCode(),
                                QuestionEnum.ENTERPRISES_NEWLY.getQuestionCode());
                        // 调取保存方法
                        insertOptions(questions.getId(), optionsList);
                    } else if (questions.getQuestion().equals(QuestionEnum.JOB_CREATION.getQuestionCode())) {
                        // 新增就业情况
                        List<String> optionsList = Arrays.asList(QuestionEnum.JOB_NAME.getQuestionCode(),
                                QuestionEnum.JOB_PERSONNAME.getQuestionCode(),
                                QuestionEnum.JOB_EVIDENCE.getQuestionCode(),
                                QuestionEnum.JOB_ADDPOST.getQuestionCode());
                        // 调取保存方法
                        insertOptions(questions.getId(), optionsList);
                    } else if (questions.getQuestion().equals(QuestionEnum.ENTREPRENEURSHIP_COURSES.getQuestionCode())) {
                        // 开设创新创业课程情况
                        List<String> optionsList = Arrays.asList(QuestionEnum.ENTREPRENEURSHIP_NAME.getQuestionCode(),
                                QuestionEnum.ENTREPRENEURSHIP_TEACHER.getQuestionCode(),
                                QuestionEnum.ENTREPRENEURSHIP_HOURS.getQuestionCode(),
                                QuestionEnum.ENTREPRENEURSHIP_CREDIT.getQuestionCode(),
                                QuestionEnum.ENTREPRENEURSHIP_SCREENSHOT.getQuestionCode(),
                                QuestionEnum.ENTREPRENEURSHIP_COURSEWARE.getQuestionCode(),
                                QuestionEnum.ENTREPRENEURSHIP_INTRODUCE.getQuestionCode(),
                                QuestionEnum.ENTREPRENEURSHIP_VIDEO_DISPLAY.getQuestionCode(),
                                QuestionEnum.ENTREPRENEURSHIP_NETWORK_CONNECTION.getQuestionCode(),
                                QuestionEnum.ENTREPRENEURSHIP_DEMONSTRATION.getQuestionCode());
                        // 调取保存方法
                        insertOptions(questions.getId(), optionsList);
                    } else if (questions.getQuestion().equals(QuestionEnum.ENTREPRENEURSHIP_MENTOR.getQuestionCode())) {
                        // 签约创业导师情况
                        List<String> optionsList = Arrays.asList(QuestionEnum.MENTOR_TNAME.getQuestionCode(),
                                QuestionEnum.MENTOR_SEX.getQuestionCode(),
                                QuestionEnum.MENTOR_EDUCATIONAL.getQuestionCode(),
                                QuestionEnum.MENTOR_PHONE.getQuestionCode(),
                                QuestionEnum.MENTOR_UNIT.getQuestionCode(),
                                QuestionEnum.MENTOR_POSITION.getQuestionCode(),
                                QuestionEnum.MENTOR_PROFESSIONA.getQuestionCode(),
                                QuestionEnum.MENTOR_SIGNING_DATE.getQuestionCode(),
                                QuestionEnum.MENTOR_SIGNING_DURATION.getQuestionCode(),
                                QuestionEnum.MENTOR_TUTORING_CATEGORY.getQuestionCode(),
                                QuestionEnum.MENTOR_TUTORING_INDUSTRY.getQuestionCode(),
                                QuestionEnum.MENTOR_INTERNET_COMPETITION.getQuestionCode(),
                                QuestionEnum.MENTOR_PARTICIPATION_YEAR.getQuestionCode(),
                                QuestionEnum.MENTOR_GUIDE_TRACK.getQuestionCode(),
                                QuestionEnum.MENTOR_SUPPORTING_MATERIAL.getQuestionCode(),
                                QuestionEnum.MENTOR_ENTREPRENEURIAL_MENTOR.getQuestionCode(),
                                QuestionEnum.MENTOR_SUPPORTING_MATERIAL_ONE.getQuestionCode());
                        // 调取保存方法
                        insertOptions(questions.getId(), optionsList);
                    } else if (questions.getQuestion().equals(
                            QuestionEnum.ENTREPRENEURSHIP_ACTIVITIES.getQuestionCode())) {
                        // 组织双创活动情况
                        List<String> optionsList = Arrays.asList(QuestionEnum.ACTIVITIES_TIME.getQuestionCode(),
                                QuestionEnum.ACTIVITIES_THEME.getQuestionCode(),
                                QuestionEnum.ACTIVITIES_ACTIVITY_TYPE.getQuestionCode(),
                                QuestionEnum.ACTIVITIES_ACTIVITY_NEWS.getQuestionCode(),
                                QuestionEnum.ACTIVITIES_ACTIVITY_PHOTOT.getQuestionCode());
                        // 调取保存方法
                        insertOptions(questions.getId(), optionsList);
                    } else if (questions.getQuestion().equals(QuestionEnum.COMPETITION_SITUATION.getQuestionCode())) {
                        // 参赛情况
                        List<String> optionsList = Arrays.asList(QuestionEnum.SITUATION_NAME.getQuestionCode(),
                                QuestionEnum.SITUATION_UNIT.getQuestionCode(),
                                QuestionEnum.SITUATION_ENTRY_NAME.getQuestionCode());
                        // 调取保存方法
                        insertOptions(questions.getId(), optionsList);
                    } else if (questions.getQuestion().equals(
                            QuestionEnum.INNOVATION_ENTREPRENEURSHIP.getQuestionCode())) {
                        // 本年创新创业工作经费（万元）
                        List<String> optionsList = Arrays.asList(QuestionEnum.INNOVATION_APPROPRIATION.getQuestionCode(),
                                QuestionEnum.INNOVATION_PROOF_PHOTOGRAPH.getQuestionCode());
                        // 调取保存方法
                        insertOptions(questions.getId(), optionsList);
                    } else if (questions.getQuestion().equals(QuestionEnum.MAKER_INFORMATION.getQuestionCode())) {
                        // 申报成功高校众创空间联盟发布的创新创业研究课题信息
                        List<String> optionsList = Arrays.asList(QuestionEnum.MAKER_SUBJECT_NUMBER.getQuestionCode(),
                                QuestionEnum.MAKER_SUBJECT_NAME.getQuestionCode(),
                                QuestionEnum.MAKER_SUBJECT_PERSON.getQuestionCode());
                        // 调取保存方法
                        insertOptions(questions.getId(), optionsList);
                    } else if (questions.getQuestion().equals(QuestionEnum.INCUBATED_ENTERPRISE.getQuestionCode())) {
                        // 在孵企业销售收入或累计合同额情况
                        List<String> optionsList = Arrays.asList(QuestionEnum.INCUBATED_NAME.getQuestionCode(),
                                QuestionEnum.INCUBATED_AMOUNT.getQuestionCode(),
                                QuestionEnum.INCUBATED_MATERIAL.getQuestionCode());
                        // 调取保存方法
                        insertOptions(questions.getId(), optionsList);
                    } else if (questions.getQuestion().equals(QuestionEnum.DEBT_FINANCING.getQuestionCode())) {
                        // 本评估周期实现股权或债权融资情况（含股东增资或股东借款）
                        List<String> optionsList = Arrays.asList(
                                QuestionEnum.INCUBATED_FINANCING_NAME.getQuestionCode(),
                                QuestionEnum.INCUBATED_FINANCING_AMOUNT.getQuestionCode(),
                                QuestionEnum.INCUBATED_FINANCING_MODE.getQuestionCode(),
                                QuestionEnum.INCUBATED_MATERIAL_ONE.getQuestionCode());
                        // 调取保存方法
                        insertOptions(questions.getId(), optionsList);
                    } else if (questions.getQuestion().equals(QuestionEnum.WEEK_ACTIVITIES.getQuestionCode())) {
                        // 主办或承办市级及以上级别路演、双创周活动
                        List<String> optionsList = Arrays.asList(QuestionEnum.ACTIVITIES_NAME.getQuestionCode(),
                                QuestionEnum.ACTIVITIES_DEVELOPMENT.getQuestionCode(),
                                QuestionEnum.ACTIVITIES_HOST.getQuestionCode());
                        // 调取保存方法
                        insertOptions(questions.getId(), optionsList);
                    } else if (questions.getQuestion().equals(QuestionEnum.LISTING_SITUATION.getQuestionCode())) {
                        // 在孵企业在OTC高校板挂牌情况
                        List<String> optionsList = Arrays.asList(QuestionEnum.SITUATION_BATCH.getQuestionCode(),
                                QuestionEnum.SITUATION_PROJECT_NAME.getQuestionCode());
                        // 调取保存方法
                        insertOptions(questions.getId(), optionsList);
                    } else if (questions.getQuestion().equals(QuestionEnum.PROPERTY_RIGHTS.getQuestionCode())) {
                        // 在孵企业新增知识产权（包括专利、软著等）
                        List<String> optionsList = Arrays.asList(QuestionEnum.PROPERTY_NAME.getQuestionCode(),
                                QuestionEnum.PROPERTY_TIME.getQuestionCode(),
                                QuestionEnum.PROPERTY_PROPERTY.getQuestionCode(),
                                QuestionEnum.PROPERTY_NYMBER.getQuestionCode(),
                                QuestionEnum.PROPERTY_SEND.getQuestionCode());
                        // 调取保存方法
                        insertOptions(questions.getId(), optionsList);
                    } else if (questions.getQuestion().equals(QuestionEnum.AWARD_SITUATION.getQuestionCode())) {
                        // 获得“互联网+”大赛全国赛事奖项情况
                        List<String> optionsList = Arrays.asList(QuestionEnum.AWARD_TRACK.getQuestionCode(),
                                QuestionEnum.AWARD_AWARD.getQuestionCode(),
                                QuestionEnum.AWARD_TEAM.getQuestionCode(),
                                QuestionEnum.AWARD_PROJECT.getQuestionCode(),
                                QuestionEnum.AWARD_SEND.getQuestionCode());
                        // 调取保存方法
                        insertOptions(questions.getId(), optionsList);
                    } else if (questions.getQuestion().equals(QuestionEnum.AWARDS_COMPETITION.getQuestionCode())) {
                        // 获得创客马拉松大赛及市教委组织的其他双创大赛奖项情况
                        List<String> optionsList = Arrays.asList(QuestionEnum.COMPETITION_NAME.getQuestionCode(),
                                QuestionEnum.COMPETITION_ORGANIZATION.getQuestionCode(),
                                QuestionEnum.COMPETITION_AWARD.getQuestionCode(),
                                QuestionEnum.COMPETITION_TEAM.getQuestionCode(),
                                QuestionEnum.COMPETITION_PROJECT.getQuestionCode(),
                                QuestionEnum.COMPETITION_SEND.getQuestionCode());
                        // 调取保存方法
                        insertOptions(questions.getId(), optionsList);
                    } else if (questions.getQuestion().equals(QuestionEnum.TOPSTATUS.getQuestionCode())) {
                        // 入选天津市创业拔尖项目情况
                        List<String> optionsList = Arrays.asList(QuestionEnum.TOPSTATUS_YEAR.getQuestionCode(),
                                QuestionEnum.TOPSTATUS_NAME.getQuestionCode(),
                                QuestionEnum.TOPSTATUS_ITEM.getQuestionCode(),
                                QuestionEnum.TOPSTATUS_EXCELLENT_PROJECT.getQuestionCode());
                        // 调取保存方法
                        insertOptions(questions.getId(), optionsList);
                    } else if (questions.getQuestion().equals(QuestionEnum.NATIONAL_RECORD.getQuestionCode())) {
                        // 是否为国家级备案众创空间
                        List<String> optionsList = Arrays.asList(QuestionEnum.BOOLEAN_NATIONAL_RECORD.getQuestionCode());
                        // 调取保存方法
                        insertOptions(questions.getId(), optionsList);
                    } else if (questions.getQuestion().equals(
                            QuestionEnum.NATIONAL_ENTREPRENEURSHIP.getQuestionCode())) {
                        // 是否为国家创业孵化示范基地
                        List<String> optionsList = Arrays.asList(
                                QuestionEnum.BOOLEAN_NATIONAL_ENTREPRENEURSHIP.getQuestionCode());
                        // 调取保存方法
                        insertOptions(questions.getId(), optionsList);
                    }
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        return String.valueOf(rtn);
    }

    /**
     * 保存选项表数据
     */
    private int insertOptions(Long id, List<String> optionsList) {
        Calendar calendar = Calendar.getInstance();
        if (StringUtils.isEmpty(String.valueOf(id))) {
            return 0;
        }
        int rtn = 0;
        int qn_year = calendar.get(Calendar.YEAR);
        Options options = new Options();
        // 获取问题表主键
        options.setQuestionId(id);
        for (String str : optionsList) {

            Options option = questionnaireDao.queryOptionByTitle(str, qn_year - 1).get(0);

            options.setFormTag(option.getFormTag());
            options.setFormOption(option.getFormOption());
            options.setQnYear(qn_year);
            options.setOptionValue(str);
            options.setStatus(1);
            rtn = questionnaireDao.insertOptions(options);
        }
        return rtn;
    }

    /**
     * 每年生成上报记录数据
     */
    @Override
    public Map<String, Object> generateRecordTask() {
        Map<String, Object> tblMap = new HashMap<>();
        Long rtn = 0L;
        try {
            // 获取系统当前年
            Calendar calendar = Calendar.getInstance();
            // 查询问卷表的年份和问卷名称
            Questionnaire questionnaire = questionnaireDao.queryQuestionnaireList(calendar.get(Calendar.YEAR));
            // 查询上报记录相关数据，用于保存数据使用
            Record record = new Record();
            List<Record> recordList = questionnaireDao.queryRecordList(record);
            if (recordList != null || questionnaire != null) {
                for (Record rd : recordList) {
                    // 创建对象
                    Record recordTbl = new Record();
                    recordTbl.setQuestionnaireUuid(questionnaire.getId());
                    recordTbl.setQuestionnaireName(questionnaire.getQuestionnaireName());
                    recordTbl.setProcessStatus(rd.getProcessStatus());
                    recordTbl.setCreateTime(new Date());
                    recordTbl.setCreateBy(rd.getCreateBy());
                    recordTbl.setWritePeople(rd.getWritePeople());
                    recordTbl.setPhoneNumber(rd.getPhoneNumber());
                    recordTbl.setCreateId(rd.getCreateId());
                    recordTbl.setQnYear(calendar.get(Calendar.YEAR));
                    rtn = questionnaireDao.insertRecord(recordTbl);
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }

        if (rtn > 0) {
            tblMap.put("code", 200);
            tblMap.put("result", true);
            tblMap.put("msg", "生成数据表成功！");
            return tblMap;
        } else {
            tblMap.put("code", 500);
            tblMap.put("result", false);
            tblMap.put("msg", "生成数据表失败！");
            return tblMap;
        }
    }

    @Override
    public List<Record> AboutViewList(Record record) {
        return questionnaireDao.AboutViewList(record);
    }

    @Override
    public List<Record> CountYearId(Record record) {
        return questionnaireDao.CountYearId(record);
    }

    @Override
    public List<Questionnaire> CountYearIdQuestion(Questionnaire questionnaire) {
        return questionnaireDao.CountYearIdQuestion(questionnaire);
    }

    @Override
    public List<Record> AboutViewListCopy(Record record) {
        return questionnaireDao.AboutViewListCopy(record);
    }

    @Override
    public List<Options> queryArray(Options options) {
        return questionnaireDao.queryArray(options);
    }

    /**
     * 2023年修改导出问卷管理-审批页面根据基础指标、引导指标和奖励指标导出所有空间的数据
     *
     * @param request
     * @param response
     * @param index    区分指标
     * @param recordId 上报记录id
     */
    @Override
    public void exportFullTimeWorkPersonNew(HttpServletRequest request, HttpServletResponse response, String index, String recordId, Integer qnYear, String createId,
                                            Integer id1, Integer id2, Integer id3,
                                            Integer id9, Integer id10, Integer id11, Integer id12, Integer id13, Integer id14,
                                            Integer id16, Integer id17, Integer id18, Integer id19, Integer id20,
                                            Integer id21, Integer id22, Integer id23, Integer id24,
                                            Integer id25, Integer id26, Integer id27, Integer id28, Integer id29, Integer id30, Integer id31, Integer id32, Integer id33, Integer id34,
                                            Integer id35, Integer id36, Integer id37, Integer id38, Integer id39, Integer id40, Integer id41, Integer id42, Integer id43, Integer id44, Integer id45, Integer id46, Integer id47, Integer id48, Integer id49, Integer id50, Integer id51,
                                            Integer id52, Integer id53, Integer id54, Integer id55, Integer id56,
                                            Integer id57, Integer id58, Integer id59,
                                            Integer id60,
                                            Integer id62, Integer id63, Integer id64,
                                            Integer id65, Integer id66, Integer id67,
                                            Integer id68, Integer id69, Integer id70, Integer id71,
                                            Integer id72, Integer id73, Integer id74,
                                            Integer id75, Integer id76,
                                            Integer id77, Integer id78, Integer id79, Integer id80, Integer id81,
                                            Integer id82, Integer id83, Integer id84, Integer id85, Integer id86,
                                            Integer id87, Integer id88, Integer id89, Integer id90, Integer id91, Integer id92,
                                            Integer id93, Integer id94, Integer id95, Integer id96,
                                            Integer id97, Integer id98
    ) {
        try {
            WriteCellStyle headWriteCellStyle = new WriteCellStyle();
            //设置背景颜色
            headWriteCellStyle.setFillForegroundColor(IndexedColors.GREY_25_PERCENT.getIndex());
            //设置头字体
            WriteFont headWriteFont = new WriteFont();
            headWriteFont.setFontHeightInPoints((short) 10);
            headWriteFont.setBold(true);
            headWriteCellStyle.setWriteFont(headWriteFont);
            //设置头居中
            headWriteCellStyle.setHorizontalAlignment(HorizontalAlignment.CENTER);
            //内容策略
            WriteCellStyle contentWriteCellStyle = new WriteCellStyle();
            //设置 自动换行
            contentWriteCellStyle.setWrapped(true);
            //设置 垂直对齐
            contentWriteCellStyle.setVerticalAlignment(VerticalAlignment.CENTER);
            //设置 水平居中
            contentWriteCellStyle.setHorizontalAlignment(HorizontalAlignment.CENTER);
            // 这个策略是 头是头的样式 内容是内容的样式
            HorizontalCellStyleStrategy horizontalCellStyleStrategy =
                    new HorizontalCellStyleStrategy(headWriteCellStyle, contentWriteCellStyle);

            response.setContentType("application/vnd.ms-excel;charset=UTF-8");
            response.setCharacterEncoding("UTF-8");

            //需要合并的列
            int[] mergeColumnIndex = {0, 1};
            // 从第二行后开始合并
            int mergeRowIndex = 1;

            switch (index) {
                case "1":
                    //导出文件名称
                    String fileName_a = "基础指标一";
                    response.setHeader("Content-disposition", "attachment;filename=" +
                            new String((fileName_a).getBytes("gb2312"),
                                    "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<SiteCondition> siteConditionList = questionnaireDao.selectSiteConditionListTemp(recordId, qnYear, createId, id1, id2, id3);
                    if (siteConditionList != null) {
                        for (int i = 0; i < siteConditionList.size(); i++) {
                            //excel生成序号
                            siteConditionList.get(i).setIndex(i + 1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(), SiteCondition.class)
                                .sheet("众创空间场地情况与是否租赁场地").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .doWrite(siteConditionList);
                        response.flushBuffer();
                    }
                    break;
                case "2":
                    //导出文件名称
                    String fileName_b = "基础指标二";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_b).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<FullTimeWorkPerson> fullTimeWorkPersonList = questionnaireDao.selectFullTimeWorkPersonListNew(recordId, qnYear, createId, id9, id10, id11, id12, id13, id14);
                    if (fullTimeWorkPersonList != null) {
                        for (int i = 0; i < fullTimeWorkPersonList.size(); i++) {
                            //excel生成序号
                            fullTimeWorkPersonList.get(i).setIndex(i + 1);
                        }
                        // 创建新列表保存拆分后的数据
                        List<FullTimeWorkPerson> personList = new ArrayList<>();
                        for (FullTimeWorkPerson enterprise : fullTimeWorkPersonList) {
                            // 拆分字段的逗号分隔值
                            String[] name = enterprise.getName().split(",");
                            String[] office = enterprise.getOffice().split(",");
                            String[] dpt = enterprise.getDpt().split(",");
                            String[] spacePosition = enterprise.getSpacePosition().split(",");
                            String[] phone = enterprise.getPhone().split(",");
                            String[] isfulltime = enterprise.getIsfulltime().split(",");

                            int maxDataCount = Math.max(Math.max(Math.max(Math.max(Math.max(name.length, office.length), dpt.length), spacePosition.length), phone.length), isfulltime.length);

                            // 处理每个拆分后的数据项
                            for (int i = 0; i < maxDataCount; i++) {
                                FullTimeWorkPerson row = new FullTimeWorkPerson();
                                row.setIndex(enterprise.getIndex());
                                row.setSpaceName(enterprise.getSpaceName());
                                row.setName(getSplitValue(name, i));
                                row.setOffice(getSplitValue(office, i));
                                row.setDpt(getSplitValue(dpt, i));
                                row.setSpacePosition(getSplitValue(spacePosition, i));
                                row.setPhone(getSplitValue(phone, i));
                                row.setIsfulltime(getSplitValue(isfulltime, i));
                                personList.add(row);
                            }
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(), FullTimeWorkPerson.class).sheet("众创空间场地情况").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .doWrite(personList);
                        response.flushBuffer();
                    }
                    break;
                case "3":
                    //导出文件名称
                    String fileName_c = "基础指标三";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_c).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<IncubatedEnterprises> incubatedEnterprisesList = questionnaireDao.selectIncubatedEnterprisesListNew(qnYear, createId, id16, id17, id18, id19, id20);
                    if (incubatedEnterprisesList != null) {
                        for (int i = 0; i < incubatedEnterprisesList.size(); i++) {
                            //excel生成序号
                            incubatedEnterprisesList.get(i).setIndex(i + 1);
                        }
                        // 创建新列表保存拆分后的数据
                        List<IncubatedEnterprises> splitIncubatedEnterprisesList = new ArrayList<>();
                        for (IncubatedEnterprises enterprise : incubatedEnterprisesList) {
                            // 拆分字段的逗号分隔值
                            String[] enterpriseNames = enterprise.getEnterpriseName().split(",");
                            String[] isSubmitScreenshots = enterprise.getIsSubmitScreenshot().split(",");
                            String[] isSubmitCertificates = enterprise.getIsSubmitCertificate().split(",");
                            String[] isSubmitIncubations = enterprise.getIsSubmitIncubation().split(",");
                            String[] isEntryYears = enterprise.getIsEntryYear().split(",");
                            int maxDataCount = Math.max(Math.max(Math.max(enterpriseNames.length, isSubmitScreenshots.length), isSubmitCertificates.length), Math.max(isSubmitIncubations.length, isEntryYears.length));
                            // 处理每个拆分后的数据项
                            for (int i = 0; i < maxDataCount; i++) {
                                IncubatedEnterprises row = new IncubatedEnterprises();
                                row.setIndex(enterprise.getIndex());
                                row.setSpaceName(enterprise.getSpaceName());
                                row.setEnterpriseName(getSplitValue(enterpriseNames, i));
                                row.setIsSubmitScreenshot(getSplitValue(isSubmitScreenshots, i));
                                row.setIsSubmitCertificate(getSplitValue(isSubmitCertificates, i));
                                row.setIsSubmitIncubation(getSplitValue(isSubmitIncubations, i));
                                row.setIsEntryYear(getSplitValue(isEntryYears, i));

                                splitIncubatedEnterprisesList.add(row);
                            }
                        }

                        //生成excel
                        EasyExcel.write(response.getOutputStream(), IncubatedEnterprises.class).sheet("入孵企业情况").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .doWrite(splitIncubatedEnterprisesList);
                        response.flushBuffer();
                    }
                    break;
                case "4":
                    //导出文件名称
                    String fileName_d = "基础指标四";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_d).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<EmploymentSituation> employmentSituationList = questionnaireDao.selectEmploymentSituationListNew(qnYear, createId, id21, id22, id23, id24);
                    if (employmentSituationList != null) {
                        for (int i = 0; i < employmentSituationList.size(); i++) {
                            //excel生成序号
                            employmentSituationList.get(i).setIndex(i + 1);
                        }
                        List<EmploymentSituation> list = new ArrayList<>();
                        for (EmploymentSituation item : employmentSituationList) {
                            // 拆分字段的逗号分隔值
                            String[] enterpriseNames = item.getEnterpriseName().split(",");
                            String[] employName = item.getEmployName().split(",");
                            String[] isAgreementMaterials = item.getIsAgreementMaterials().split(",");
                            String[] isAssessmentPeriod = item.getIsAssessmentPeriod().split(",");
                            int maxDataCount = Math.max(Math.max(enterpriseNames.length, employName.length), Math.max(isAgreementMaterials.length, isAssessmentPeriod.length));
                            // 处理每个拆分后的数据项
                            for (int i = 0; i < maxDataCount; i++) {
                                EmploymentSituation row = new EmploymentSituation();
                                row.setIndex(item.getIndex());
                                row.setSpaceName(item.getSpaceName());
                                row.setEnterpriseName(getSplitValue(enterpriseNames, i));
                                row.setEmployName(getSplitValue(employName, i));
                                row.setIsAgreementMaterials(getSplitValue(isAgreementMaterials, i));
                                row.setIsAssessmentPeriod(getSplitValue(isAssessmentPeriod, i));
                                list.add(row);
                            }
                        }

                        //生成excel
                        EasyExcel.write(response.getOutputStream(), EmploymentSituation.class).sheet("新增就业情况").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .doWrite(list);
                        response.flushBuffer();
                    }
                    break;
                case "5":
                    //导出文件名称
                    String fileName_e = "基础指标五";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_e).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<EntrepreneurshipCourses> entrepreneurshipCoursesList = questionnaireDao.selectEntrepreneurshipCoursesListNew(qnYear, createId, id25, id26, id27, id28, id29, id30, id31, id32, id33, id34);
                    if (entrepreneurshipCoursesList != null) {
                        for (int i = 0; i < entrepreneurshipCoursesList.size(); i++) {
                            //excel生成序号
                            entrepreneurshipCoursesList.get(i).setIndex(i + 1);
                        }
                        List<EntrepreneurshipCourses> list = new ArrayList<>();
                        for (EntrepreneurshipCourses item : entrepreneurshipCoursesList) {
                            // 拆分字段的逗号分隔值
                            String[] courseName = item.getCourseName().split(",");
                            String[] teacher = item.getTeacher().split(",");
                            String[] school = item.getSchool().split(",");
                            String[] credits = item.getCredits().split(",");
                            String[] isScreenshotOrExport = item.getIsScreenshotOrExport().split(",");
                            String[] isSystem = item.getIsSystem().split(",");
                            String[] islectureCourseware = item.getIslectureCourseware().split(",");
                            String[] isPresentation = item.getIsPresentation().split(",");
                            String[] isNetworkConnection = item.getIsNetworkConnection().split(",");
                            String[] alliance = item.getAlliance().split(",");
                            int maxDataCount = Math.max(courseName.length,
                                    Math.max(teacher.length,
                                            Math.max(school.length,
                                                    Math.max(credits.length,
                                                            Math.max(isScreenshotOrExport.length,
                                                                    Math.max(isSystem.length,
                                                                            Math.max(islectureCourseware.length,
                                                                                    Math.max(isPresentation.length,
                                                                                            Math.max(isNetworkConnection.length,
                                                                                                    alliance.length)))))))));
                            for (int i = 0; i < maxDataCount; i++) {
                                EntrepreneurshipCourses row = new EntrepreneurshipCourses();
                                row.setIndex(item.getIndex());
                                row.setSpaceName(item.getSpaceName());
                                row.setCourseName(getSplitValue(courseName, i));
                                row.setTeacher(getSplitValue(teacher, i));
                                row.setSchool(getSplitValue(school, i));
                                row.setCredits(getSplitValue(credits, i));
                                row.setIsScreenshotOrExport(getSplitValue(isScreenshotOrExport, i));
                                row.setIsSystem(getSplitValue(isSystem, i));
                                row.setIslectureCourseware(getSplitValue(islectureCourseware, i));
                                row.setIsPresentation(getSplitValue(isPresentation, i));
                                row.setIsNetworkConnection(getSplitValue(isNetworkConnection, i));
                                row.setAlliance(getSplitValue(alliance, i));
                                list.add(row);
                            }
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(), EntrepreneurshipCourses.class).sheet("开设创新创业课程情况").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .doWrite(list);
                        response.flushBuffer();
                    }
                    break;
                case "6":
                    //导出文件名称
                    String fileName_f = "基础指标六";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_f).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<SigningMentors> signingMentorsList = questionnaireDao.selectSigningMentorsListNew(qnYear, createId, id35, id36, id37, id38, id39, id40, id41, id42, id43, id44, id45, id46, id47, id48, id49, id50, id51);
                    if (signingMentorsList != null) {
                        for (int i = 0; i < signingMentorsList.size(); i++) {
                            //excel生成序号
                            signingMentorsList.get(i).setIndex(i + 1);
                        }
                        List<SigningMentors> list = new ArrayList<>();
                        for (SigningMentors item : signingMentorsList) {
                            // 拆分字段的逗号分隔值
                            String[] mentorName = item.getMentorName().split(",");
                            String[] gender = item.getGender().split(",");
                            String[] record = item.getRecord().split(",");
                            String[] phoneNumber = item.getPhoneNumber().split(",");
                            String[] unit = item.getUnit().split(",");
                            String[] position = item.getPosition().split(",");
                            String[] theTitle = item.getTheTitle().split(",");
                            String[] signingDate = item.getSigningDate().split(",");
                            String[] contractTime = item.getContractTime().split(",");
                            String[] coachingCategory = item.getCoachingCategory().split(",");
                            String[] coaching = item.getCoaching().split(",");
                            String[] participated = item.getParticipated().split(",");
                            String[] contestantYear = item.getContestantYear().split(",");
                            String[] guideTrack = item.getGuideTrack().split(",");
                            String[] isMaterials = item.getIsMaterials().split(",");
                            String[] mentor = item.getMentor().split(",");
                            String[] isSupporting = item.getIsSupporting().split(",");
                            int[] maxLen = {
                                    mentorName.length,
                                    gender.length,
                                    record.length,
                                    phoneNumber.length,
                                    unit.length,
                                    position.length,
                                    theTitle.length,
                                    signingDate.length,
                                    contractTime.length,
                                    coachingCategory.length,
                                    coaching.length,
                                    participated.length,
                                    contestantYear.length,
                                    guideTrack.length,
                                    isMaterials.length,
                                    mentor.length,
                                    isSupporting.length
                            };
                            int maxDataCount = max(maxLen);
                            // 处理每个拆分后的数据项
                            for (int i = 0; i < maxDataCount; i++) {
                                SigningMentors row = new SigningMentors();
                                row.setIndex(item.getIndex());
                                row.setSpaceName(item.getSpaceName());
                                row.setMentorName(getSplitValue(mentorName, i));
                                row.setGender(getSplitValue(gender, i));
                                row.setRecord(getSplitValue(record, i));
                                row.setPhoneNumber(getSplitValue(phoneNumber, i));
                                row.setUnit(getSplitValue(unit, i));
                                row.setPosition(getSplitValue(position, i));
                                row.setTheTitle(getSplitValue(theTitle, i));
                                row.setSigningDate(getSplitValue(signingDate, i));
                                row.setContractTime(getSplitValue(contractTime, i));
                                row.setCoachingCategory(getSplitValue(coachingCategory, i));
                                row.setCoaching(getSplitValue(coaching, i));
                                row.setParticipated(getSplitValue(participated, i));
                                row.setContestantYear(getSplitValue(contestantYear, i));
                                row.setGuideTrack(getSplitValue(guideTrack, i));
                                row.setIsMaterials(getSplitValue(isMaterials, i));
                                row.setMentor(getSplitValue(mentor, i));
                                row.setIsSupporting(getSplitValue(isSupporting, i));
                                list.add(row);
                            }
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(), SigningMentors.class).sheet("签约创业导师情况").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .doWrite(list);
                        response.flushBuffer();
                    }
                    break;
                case "7":
                    //导出文件名称
                    String fileName_g = "基础指标七";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_g).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<OrganizationActivity> organizationActivityList = questionnaireDao.selectOrganizationActivityListNew(qnYear, createId, id52, id53, id54, id55, id56);
                    if (organizationActivityList != null) {
                        for (int i = 0; i < organizationActivityList.size(); i++) {
                            //excel生成序号
                            organizationActivityList.get(i).setIndex(i + 1);
                        }
                        List<OrganizationActivity> list = new ArrayList<>();
                        for (OrganizationActivity item : organizationActivityList) {
                            // 拆分字段的逗号分隔值
                            String[] activityTime = item.getActivityTime().split(",");
                            String[] theme = item.getTheme().split(",");
                            String[] activityType = item.getActivityType().split(",");
                            String[] platformNews = item.getPlatformNews().split(",");
                            String[] platformNewsPhoto = item.getPlatformNewsPhoto().split(",");
                            int[] maxLen = {
                                    activityTime.length,
                                    theme.length,
                                    activityType.length,
                                    platformNews.length,
                                    platformNewsPhoto.length};
                            int maxDataCount = max(maxLen);
                            // 处理每个拆分后的数据项
                            for (int i = 0; i < maxDataCount; i++) {
                                OrganizationActivity row = new OrganizationActivity();
                                row.setIndex(item.getIndex());
                                row.setSpaceName(item.getSpaceName());
                                row.setActivityTime(getSplitValue(activityTime, i));
                                row.setTheme(getSplitValue(theme, i));
                                row.setActivityType(getSplitValue(activityType, i));
                                row.setPlatformNews(getSplitValue(platformNews, i));
                                row.setPlatformNewsPhoto(getSplitValue(platformNewsPhoto, i));
                                list.add(row);
                            }
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(), OrganizationActivity.class).sheet("组织双创活动情况").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .doWrite(list);
                        response.flushBuffer();
                    }
                    break;
                case "8":
                    //导出文件名称
                    String fileName_h = "基础指标八";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_h).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<CompetingSituation> competingSituationList = questionnaireDao.selectCompetingSituationListNew(qnYear, createId, id57, id58, id59);
                    if (competingSituationList != null) {
                        for (int i = 0; i < competingSituationList.size(); i++) {
                            //excel生成序号
                            competingSituationList.get(i).setIndex(i + 1);
                        }
                        List<CompetingSituation> list = new ArrayList<>();
                        for (CompetingSituation item : competingSituationList) {
                            // 拆分字段的逗号分隔值
                            String[] eventName = item.getEventName().split(",");
                            String[] organizer = item.getOrganizer().split(",");
                            String[] projectName = item.getProjectName().split(",");
                            int[] maxLen = {
                                    eventName.length,
                                    organizer.length,
                                    projectName.length
                            };
                            int maxDataCount = max(maxLen);
                            // 处理每个拆分后的数据项
                            for (int i = 0; i < maxDataCount; i++) {
                                CompetingSituation row = new CompetingSituation();
                                row.setIndex(item.getIndex());
                                row.setSpaceName(item.getSpaceName());
                                row.setEventName(getSplitValue(eventName, i));
                                row.setOrganizer(getSplitValue(organizer, i));
                                row.setProjectName(getSplitValue(projectName, i));
                                list.add(row);
                            }
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(), CompetingSituation.class).sheet("参赛情况").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .doWrite(list);
                        response.flushBuffer();
                    }
                    break;
                case "9":
                    //导出文件名称
                    String fileName_j = "基础指标九";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_j).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<EntrepreneurshipFunding> entrepreneurshipFundingList = questionnaireDao.selectEntrepreneurshipFundingListNew(qnYear, createId, id60);
                    if (entrepreneurshipFundingList != null) {
                        for (int i = 0; i < entrepreneurshipFundingList.size(); i++) {
                            //excel生成序号
                            entrepreneurshipFundingList.get(i).setIndex(i + 1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(), EntrepreneurshipFunding.class).sheet("创新创业工作经费").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .doWrite(entrepreneurshipFundingList);
                        response.flushBuffer();
                    }
                    break;
                case "10":
                    //引导指标1 --基础指标1
                    //导出文件名称
                    String fileName_aa = "引导指标一";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_aa).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<SiteCondition> leadingIndicatorOneList = questionnaireDao.selectSiteConditionListTemp(recordId, qnYear, createId, id1, id2, id3);
                    if (leadingIndicatorOneList != null) {
                        for (int i = 0; i < leadingIndicatorOneList.size(); i++) {
                            //excel生成序号
                            leadingIndicatorOneList.get(i).setIndex(i + 1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(), SiteCondition.class).sheet("引导指标一").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .doWrite(leadingIndicatorOneList);
                        response.flushBuffer();
                    }
                    break;
                case "11":
                    //引导指标2 --基础指标1
                    //导出文件名称
                    String fileName_bb = "引导指标二";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_bb).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<SiteCondition> leadingIndicatorTwoList = questionnaireDao.selectSiteConditionListTemp(recordId, qnYear, createId, id1, id2, id3);
                    if (leadingIndicatorTwoList != null) {
                        for (int i = 0; i < leadingIndicatorTwoList.size(); i++) {
                            //excel生成序号
                            leadingIndicatorTwoList.get(i).setIndex(i + 1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(), SiteCondition.class).sheet("引导指标二").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .doWrite(leadingIndicatorTwoList);
                        response.flushBuffer();
                    }
                    break;
                case "12":
                    //引导指标3 --基础指标3
                    //导出文件名称
                    String fileName_cc = "引导指标三";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_cc).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<IncubatedEnterprises> leadingIndicatorThreeList = questionnaireDao.selectIncubatedEnterprisesListNew(qnYear, createId, id16, id17, id18, id19, id20);
                    if (leadingIndicatorThreeList != null) {
                        for (int i = 0; i < leadingIndicatorThreeList.size(); i++) {
                            //excel生成序号
                            leadingIndicatorThreeList.get(i).setIndex(i + 1);
                        }
                        // 创建新列表保存拆分后的数据
                        List<IncubatedEnterprises> splitIncubatedEnterprisesList = new ArrayList<>();
                        for (IncubatedEnterprises enterprise : leadingIndicatorThreeList) {
                            // 拆分字段的逗号分隔值
                            String[] enterpriseNames = enterprise.getEnterpriseName().split(",");
                            String[] isSubmitScreenshots = enterprise.getIsSubmitScreenshot().split(",");
                            String[] isSubmitCertificates = enterprise.getIsSubmitCertificate().split(",");
                            String[] isSubmitIncubations = enterprise.getIsSubmitIncubation().split(",");
                            String[] isEntryYears = enterprise.getIsEntryYear().split(",");
                            int maxDataCount = Math.max(Math.max(Math.max(enterpriseNames.length, isSubmitScreenshots.length), isSubmitCertificates.length), Math.max(isSubmitIncubations.length, isEntryYears.length));
                            // 处理每个拆分后的数据项
                            for (int i = 0; i < maxDataCount; i++) {
                                IncubatedEnterprises row = new IncubatedEnterprises();
                                row.setIndex(enterprise.getIndex());
                                row.setSpaceName(enterprise.getSpaceName());
                                row.setEnterpriseName(getSplitValue(enterpriseNames, i));
                                row.setIsSubmitScreenshot(getSplitValue(isSubmitScreenshots, i));
                                row.setIsSubmitCertificate(getSplitValue(isSubmitCertificates, i));
                                row.setIsSubmitIncubation(getSplitValue(isSubmitIncubations, i));
                                row.setIsEntryYear(getSplitValue(isEntryYears, i));

                                splitIncubatedEnterprisesList.add(row);
                            }
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(), IncubatedEnterprises.class).sheet("引导指标三").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .doWrite(splitIncubatedEnterprisesList);
                        response.flushBuffer();
                    }
                    break;
                case "13":
                    //引导指标4 --基础指标3
                    //导出文件名称
                    String fileName_dd = "引导指标四";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_dd).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<IncubatedEnterprises> leadingIndicatorFoureList = questionnaireDao.selectIncubatedEnterprisesListFour(qnYear, createId, id16, id17, id18, id19, id20);
                    if (leadingIndicatorFoureList != null) {
                        for (int i = 0; i < leadingIndicatorFoureList.size(); i++) {
                            //excel生成序号
                            leadingIndicatorFoureList.get(i).setIndex(i + 1);
                        }
                        // 创建新列表保存拆分后的数据
                        List<IncubatedEnterprises> splitIncubatedEnterprisesList = new ArrayList<>();
                        for (IncubatedEnterprises enterprise : leadingIndicatorFoureList) {
                            // 拆分字段的逗号分隔值
                            String[] enterpriseNames = enterprise.getEnterpriseName().split(",");
                            String[] isSubmitScreenshots = enterprise.getIsSubmitScreenshot().split(",");
                            String[] isSubmitCertificates = enterprise.getIsSubmitCertificate().split(",");
                            String[] isSubmitIncubations = enterprise.getIsSubmitIncubation().split(",");
                            String[] isEntryYears = enterprise.getIsEntryYear().split(",");
                            int maxDataCount = Math.max(Math.max(Math.max(enterpriseNames.length, isSubmitScreenshots.length), isSubmitCertificates.length), Math.max(isSubmitIncubations.length, isEntryYears.length));
                            // 处理每个拆分后的数据项
                            for (int i = 0; i < maxDataCount; i++) {
                                IncubatedEnterprises row = new IncubatedEnterprises();
                                row.setIndex(enterprise.getIndex());
                                row.setSpaceName(enterprise.getSpaceName());
                                row.setEnterpriseName(getSplitValue(enterpriseNames, i));
                                row.setIsSubmitScreenshot(getSplitValue(isSubmitScreenshots, i));
                                row.setIsSubmitCertificate(getSplitValue(isSubmitCertificates, i));
                                row.setIsSubmitIncubation(getSplitValue(isSubmitIncubations, i));
                                row.setIsEntryYear(getSplitValue(isEntryYears, i));
                                splitIncubatedEnterprisesList.add(row);
                            }
                        }
                        List<IncubatedEnterprises> finalList = new ArrayList<>();

                        for (IncubatedEnterprises enterprise : splitIncubatedEnterprisesList) {
                            if ("是".equals(enterprise.getIsEntryYear())) {
                                finalList.add(enterprise);
                            }
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(), IncubatedEnterprises.class).sheet("引导指标四").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .doWrite(finalList);
                        response.flushBuffer();
                    }
                    break;
                case "14":
                    //引导指标5 --基础指标4
                    //导出文件名称
                    String fileName_ee = "引导指标五";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_ee).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<EmploymentSituation> employmentSituationList1 = questionnaireDao.selectEmploymentSituationListNew(qnYear, createId, id21, id22, id23, id24);
                    if (employmentSituationList1 != null) {
                        for (int i = 0; i < employmentSituationList1.size(); i++) {
                            //excel生成序号
                            employmentSituationList1.get(i).setIndex(i + 1);
                        }
                        List<EmploymentSituation> list = new ArrayList<>();
                        for (EmploymentSituation item : employmentSituationList1) {
                            // 拆分字段的逗号分隔值
                            String[] enterpriseNames = item.getEnterpriseName().split(",");
                            String[] employName = item.getEmployName().split(",");
                            String[] isAgreementMaterials = item.getIsAgreementMaterials().split(",");
                            String[] isAssessmentPeriod = item.getIsAssessmentPeriod().split(",");
                            int maxDataCount = Math.max(Math.max(enterpriseNames.length, employName.length), Math.max(isAgreementMaterials.length, isAssessmentPeriod.length));
                            // 处理每个拆分后的数据项
                            for (int i = 0; i < maxDataCount; i++) {
                                EmploymentSituation row = new EmploymentSituation();
                                row.setIndex(item.getIndex());
                                row.setSpaceName(item.getSpaceName());
                                row.setEnterpriseName(getSplitValue(enterpriseNames, i));
                                row.setEmployName(getSplitValue(employName, i));
                                row.setIsAgreementMaterials(getSplitValue(isAgreementMaterials, i));
                                row.setIsAssessmentPeriod(getSplitValue(isAssessmentPeriod, i));
                                list.add(row);
                            }
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(), EmploymentSituation.class).sheet("新增就业情况").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .doWrite(list);
                        response.flushBuffer();
                    }
                    break;
                case "15":
                    //引导指标6
                    //导出文件名称
                    String fileName_k = "引导指标六";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_k).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    response.setContentType("application/vnd.openxmlformats-officedocument.spreadsheetml.sheet");
                    ExcelWriter excelWriter = EasyExcel.write(response.getOutputStream()).build();
                    //查询数据
                    List<EntrepreneurshipCourses> entrepreneurshipCoursesList5 = questionnaireDao.selectEntrepreneurshipCoursesListNew(qnYear, createId, id25, id26, id27, id28, id29, id30, id31, id32, id33, id34);
                    if (entrepreneurshipCoursesList5 != null) {
                        for (int i = 0; i < entrepreneurshipCoursesList5.size(); i++) {
                            //excel生成序号
                            entrepreneurshipCoursesList5.get(i).setIndex(i + 1);
                        }
                        List<EntrepreneurshipCourses> list = new ArrayList<>();
                        for (EntrepreneurshipCourses item : entrepreneurshipCoursesList5) {
                            // 拆分字段的逗号分隔值
                            String[] courseName = item.getCourseName().split(",");
                            String[] teacher = item.getTeacher().split(",");
                            String[] school = item.getSchool().split(",");
                            String[] credits = item.getCredits().split(",");
                            String[] isScreenshotOrExport = item.getIsScreenshotOrExport().split(",");
                            String[] isSystem = item.getIsSystem().split(",");
                            String[] islectureCourseware = item.getIslectureCourseware().split(",");
                            String[] isPresentation = item.getIsPresentation().split(",");
                            String[] isNetworkConnection = item.getIsNetworkConnection().split(",");
                            String[] alliance = item.getAlliance().split(",");
                            int maxDataCount = Math.max(courseName.length,
                                    Math.max(teacher.length,
                                            Math.max(school.length,
                                                    Math.max(credits.length,
                                                            Math.max(isScreenshotOrExport.length,
                                                                    Math.max(isSystem.length,
                                                                            Math.max(islectureCourseware.length,
                                                                                    Math.max(isPresentation.length,
                                                                                            Math.max(isNetworkConnection.length,
                                                                                                    alliance.length)))))))));
                            for (int i = 0; i < maxDataCount; i++) {
                                EntrepreneurshipCourses row = new EntrepreneurshipCourses();
                                row.setIndex(item.getIndex());
                                row.setSpaceName(item.getSpaceName());
                                row.setCourseName(getSplitValue(courseName, i));
                                row.setTeacher(getSplitValue(teacher, i));
                                row.setSchool(getSplitValue(school, i));
                                row.setCredits(getSplitValue(credits, i));
                                row.setIsScreenshotOrExport(getSplitValue(isScreenshotOrExport, i));
                                row.setIsSystem(getSplitValue(isSystem, i));
                                row.setIslectureCourseware(getSplitValue(islectureCourseware, i));
                                row.setIsPresentation(getSplitValue(isPresentation, i));
                                row.setIsNetworkConnection(getSplitValue(isNetworkConnection, i));
                                row.setAlliance(getSplitValue(alliance, i));
                                list.add(row);
                            }
                        }
                        WriteSheet writeSheet1 = EasyExcel.writerSheet(0, "开设创新创业课程情况")
                                .head(EntrepreneurshipCourses.class)
                                .registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .build();
                        excelWriter.write(list, writeSheet1);
                    }
                    //查询数据
                    List<EntrepreneurshipProject> entrepreneurshipProjectList = questionnaireDao.selectEntrepreneurshipProjectListNew(qnYear, createId, id62, id63, id64);
                    if (entrepreneurshipProjectList != null) {
                        for (int i = 0; i < entrepreneurshipProjectList.size(); i++) {
                            //excel生成序号
                            entrepreneurshipProjectList.get(i).setIndex(i + 1);
                        }
                        List<EntrepreneurshipProject> listT = new ArrayList<>();
                        for (EntrepreneurshipProject item : entrepreneurshipProjectList) {
                            // 拆分字段的逗号分隔值
                            String[] issueNumber = item.getIssueNumber().split(",");
                            String[] projectName = item.getProjectName().split(",");
                            String[] projectLeaderName = item.getProjectLeaderName().split(",");
                            int[] maxLen = {
                                    issueNumber.length,
                                    projectName.length,
                                    projectLeaderName.length
                            };
                            int maxDataCount = max(maxLen);
                            // 处理每个拆分后的数据项
                            for (int i = 0; i < maxDataCount; i++) {
                                EntrepreneurshipProject row = new EntrepreneurshipProject();
                                row.setIndex(item.getIndex());
                                row.setSpaceName(item.getSpaceName());
                                row.setIssueNumber(getSplitValue(issueNumber, i));
                                row.setProjectName(getSplitValue(projectName, i));
                                row.setProjectLeaderName(getSplitValue(projectLeaderName, i));
                                listT.add(row);
                            }
                        }
                        //生成excel
                        WriteSheet writeSheet0 = EasyExcel.writerSheet(1, "申报成功高校众创空间联盟发布的创新创业研究课题信息")
                                .head(EntrepreneurshipProject.class)
                                .registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .build();
                        excelWriter.write(listT, writeSheet0);
                    }
                    excelWriter.finish();
                    response.flushBuffer();
                    break;
                case "16":
                    //引导指标7 --基础指标6
                    //导出文件名称
                    String fileName_ff = "引导指标七";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_ff).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<SigningMentors> leadingIndicatorSixList = questionnaireDao.selectSigningMentorsListSeven(qnYear, createId, id35, id36, id37, id38, id39, id40, id41, id42, id43, id44, id45, id46, id47, id48, id49, id50, id51);
                    if (leadingIndicatorSixList != null) {
                        for (int i = 0; i < leadingIndicatorSixList.size(); i++) {
                            //excel生成序号
                            leadingIndicatorSixList.get(i).setIndex(i + 1);
                        }
                        List<SigningMentors> list = new ArrayList<>();
                        for (SigningMentors item : leadingIndicatorSixList) {
                            // 拆分字段的逗号分隔值
                            String[] mentorName = item.getMentorName().split(",");
                            String[] gender = item.getGender().split(",");
                            String[] record = item.getRecord().split(",");
                            String[] phoneNumber = item.getPhoneNumber().split(",");
                            String[] unit = item.getUnit().split(",");
                            String[] position = item.getPosition().split(",");
                            String[] theTitle = item.getTheTitle().split(",");
                            String[] signingDate = item.getSigningDate().split(",");
                            String[] contractTime = item.getContractTime().split(",");
                            String[] coachingCategory = item.getCoachingCategory().split(",");
                            String[] coaching = item.getCoaching().split(",");
                            String[] participated = item.getParticipated().split(",");
                            String[] contestantYear = item.getContestantYear().split(",");
                            String[] guideTrack = item.getGuideTrack().split(",");
                            String[] isMaterials = item.getIsMaterials().split(",");
                            String[] mentor = item.getMentor().split(",");
                            String[] isSupporting = item.getIsSupporting().split(",");
                            int[] maxLen = {
                                    mentorName.length,
                                    gender.length,
                                    record.length,
                                    phoneNumber.length,
                                    unit.length,
                                    position.length,
                                    theTitle.length,
                                    signingDate.length,
                                    contractTime.length,
                                    coachingCategory.length,
                                    coaching.length,
                                    participated.length,
                                    contestantYear.length,
                                    guideTrack.length,
                                    isMaterials.length,
                                    mentor.length,
                                    isSupporting.length
                            };
                            int maxDataCount = max(maxLen);
                            // 处理每个拆分后的数据项
                            for (int i = 0; i < maxDataCount; i++) {
                                SigningMentors row = new SigningMentors();
                                row.setIndex(item.getIndex());
                                row.setSpaceName(item.getSpaceName());
                                row.setMentorName(getSplitValue(mentorName, i));
                                row.setGender(getSplitValue(gender, i));
                                row.setRecord(getSplitValue(record, i));
                                row.setPhoneNumber(getSplitValue(phoneNumber, i));
                                row.setUnit(getSplitValue(unit, i));
                                row.setPosition(getSplitValue(position, i));
                                row.setTheTitle(getSplitValue(theTitle, i));
                                row.setSigningDate(getSplitValue(signingDate, i));
                                row.setContractTime(getSplitValue(contractTime, i));
                                row.setCoachingCategory(getSplitValue(coachingCategory, i));
                                row.setCoaching(getSplitValue(coaching, i));
                                row.setParticipated(getSplitValue(participated, i));
                                row.setContestantYear(getSplitValue(contestantYear, i));
                                row.setGuideTrack(getSplitValue(guideTrack, i));
                                row.setIsMaterials(getSplitValue(isMaterials, i));
                                row.setMentor(getSplitValue(mentor, i));
                                row.setIsSupporting(getSplitValue(isSupporting, i));
                                list.add(row);
                            }
                        }

                        // 用于保存过滤结果
                        List<SigningMentors> finalList = new ArrayList<>();

                        for (SigningMentors item : list) {

                            // 判断两个字段
                            if ("是".equals(item.getParticipated()) &&
                                    "是".equals(item.getMentor())) {
                                // 添加到结果列表
                                finalList.add(item);
                            }

                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(), SigningMentors.class).sheet("引导指标七").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .doWrite(finalList);
                        response.flushBuffer();
                    }
                    break;
                case "17":
                    //引导指标8 --基础指标7
                    //导出文件名称
                    String fileName_gg = "引导指标八";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_gg).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<OrganizationActivity> leadingIndicatorSevenList = questionnaireDao.selectOrganizationActivityListNew(qnYear, createId, id52, id53, id54, id55, id56);
                    if (leadingIndicatorSevenList != null) {
                        for (int i = 0; i < leadingIndicatorSevenList.size(); i++) {
                            //excel生成序号
                            leadingIndicatorSevenList.get(i).setIndex(i + 1);
                        }
                        List<OrganizationActivity> list = new ArrayList<>();
                        for (OrganizationActivity item : leadingIndicatorSevenList) {
                            // 拆分字段的逗号分隔值
                            String[] activityTime = item.getActivityTime().split(",");
                            String[] theme = item.getTheme().split(",");
                            String[] activityType = item.getActivityType().split(",");
                            String[] platformNews = item.getPlatformNews().split(",");
                            String[] platformNewsPhoto = item.getPlatformNewsPhoto().split(",");
                            int[] maxLen = {
                                    activityTime.length,
                                    theme.length,
                                    activityType.length,
                                    platformNews.length,
                                    platformNewsPhoto.length};
                            int maxDataCount = max(maxLen);
                            // 处理每个拆分后的数据项
                            for (int i = 0; i < maxDataCount; i++) {
                                OrganizationActivity row = new OrganizationActivity();
                                row.setIndex(item.getIndex());
                                row.setSpaceName(item.getSpaceName());
                                row.setActivityTime(getSplitValue(activityTime, i));
                                row.setTheme(getSplitValue(theme, i));
                                row.setActivityType(getSplitValue(activityType, i));
                                row.setPlatformNews(getSplitValue(platformNews, i));
                                row.setPlatformNewsPhoto(getSplitValue(platformNewsPhoto, i));
                                list.add(row);
                            }
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(), OrganizationActivity.class).sheet("引导指标八").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .doWrite(list);
                        response.flushBuffer();
                    }
                    break;
                case "18":
                    //引导指标9
                    //导出文件名称
                    String fileName_l = "引导指标九";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_l).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<EnterprisestAmount> enterprisestAmountList = questionnaireDao.selecEnterprisestAmountListNew(qnYear, createId, id65, id66, id67);
                    if (enterprisestAmountList != null) {
                        for (int i = 0; i < enterprisestAmountList.size(); i++) {
                            //excel生成序号
                            enterprisestAmountList.get(i).setIndex(i + 1);
                        }
                        List<EnterprisestAmount> splitIncubatedEnterprisesList = new ArrayList<>();
                        for (EnterprisestAmount enterprise : enterprisestAmountList) {
                            // 拆分字段的逗号分隔值
                            String[] enterpriseName = enterprise.getEnterpriseName().split(",");
                            String[] contractAmount = enterprise.getContractAmount().split(",");
                            String[] isSupportingMaterials = enterprise.getIsSupportingMaterials().split(",");
                            // 处理每个拆分后的数据项
                            int[] maxLen = {
                                    enterpriseName.length,
                                    contractAmount.length,
                                    isSupportingMaterials.length
                            };
                            int maxDataCount = max(maxLen);
                            for (int i = 0; i < maxDataCount; i++) {
                                EnterprisestAmount row = new EnterprisestAmount();
                                row.setIndex(enterprise.getIndex());
                                row.setSpaceName(enterprise.getSpaceName());
                                row.setEnterpriseName(getSplitValue(enterpriseName, i));
                                row.setContractAmount(getSplitValue(contractAmount, i));
                                row.setIsSupportingMaterials(getSplitValue(isSupportingMaterials, i));

                                splitIncubatedEnterprisesList.add(row);
                            }
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(), EnterprisestAmount.class).sheet("在孵企业销售收入或累计合同额情况").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .doWrite(splitIncubatedEnterprisesList);
                        response.flushBuffer();
                    }
                    break;
                case "19":
                    //引导指标10
                    //导出文件名称
                    String fileName_z = "引导指标十";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_z).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<EvaluationBorrowing> evaluationBorrowingList = questionnaireDao.selectEvaluationBorrowingListNew(qnYear, createId, id68, id69, id70, id71);
                    if (evaluationBorrowingList != null) {
                        for (int i = 0; i < evaluationBorrowingList.size(); i++) {
                            //excel生成序号
                            evaluationBorrowingList.get(i).setIndex(i + 1);
                        }
                        List<EvaluationBorrowing> list = new ArrayList<>();
                        for (EvaluationBorrowing enterprise : evaluationBorrowingList) {
                            // 拆分字段的逗号分隔值
                            String[] financingEnterpriseName = enterprise.getFinancingEnterpriseName().split(",");
                            String[] financingAmount = enterprise.getFinancingAmount().split(",");
                            String[] financingWay = enterprise.getFinancingWay().split(",");
                            String[] isSupportingMaterials = enterprise.getIsSupportingMaterials().split(",");
                            // 处理每个拆分后的数据项
                            int[] maxLen = {
                                    financingEnterpriseName.length,
                                    financingAmount.length,
                                    financingWay.length,
                                    isSupportingMaterials.length
                            };
                            int maxDataCount = max(maxLen);
                            for (int i = 0; i < maxDataCount; i++) {
                                EvaluationBorrowing row = new EvaluationBorrowing();
                                row.setIndex(enterprise.getIndex());
                                row.setSpaceName(enterprise.getSpaceName());
                                row.setFinancingEnterpriseName(getSplitValue(financingEnterpriseName, i));
                                row.setFinancingAmount(getSplitValue(financingAmount, i));
                                row.setFinancingWay(getSplitValue(financingWay, i));
                                row.setIsSupportingMaterials(getSplitValue(isSupportingMaterials, i));

                                list.add(row);
                            }
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(), EvaluationBorrowing.class).sheet("本评估周期实现股权或债权融资情况").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .doWrite(list);
                        response.flushBuffer();
                    }
                    break;
                case "20":
                    //引导指标11
                    //导出文件名称
                    String fileName_x = "引导指标十一";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_x).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<InnovationWeek> innovationWeekList = questionnaireDao.selectInnovationWeekListNew(qnYear, createId, id72, id73, id74);
                    if (innovationWeekList != null) {
                        for (int i = 0; i < innovationWeekList.size(); i++) {
                            //excel生成序号
                            innovationWeekList.get(i).setIndex(i + 1);
                        }
                        List<InnovationWeek> list = new ArrayList<>();
                        for (InnovationWeek enterprise : innovationWeekList) {
                            // 拆分字段的逗号分隔值
                            String[] activitiesName = enterprise.getActivitiesName().split(",");
                            String[] activitiesFrom = enterprise.getActivitiesFrom().split(",");
                            String[] municipalLevel = enterprise.getMunicipalLevel().split(",");
                            // 处理每个拆分后的数据项
                            int[] maxLen = {
                                    activitiesName.length,
                                    activitiesFrom.length,
                                    municipalLevel.length,
                            };
                            int maxDataCount = max(maxLen);
                            for (int i = 0; i < maxDataCount; i++) {
                                InnovationWeek row = new InnovationWeek();
                                row.setIndex(enterprise.getIndex());
                                row.setSpaceName(enterprise.getSpaceName());
                                row.setActivitiesName(getSplitValue(activitiesName, i));
                                row.setActivitiesFrom(getSplitValue(activitiesFrom, i));
                                row.setMunicipalLevel(getSplitValue(municipalLevel, i));
                                list.add(row);
                            }
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(), InnovationWeek.class).sheet("主办或承办市级及以上级别路演、双创周活动").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .doWrite(list);
                        response.flushBuffer();
                    }
                    break;
                case "21":
                    //引导指标12
                    //导出文件名称
                    String fileName_v = "引导指标十二";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_v).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<CollegeSituation> collegeSituationList = questionnaireDao.selectCollegeSituationListNew(qnYear, createId, id75, id76);
                    if (collegeSituationList != null) {
                        for (int i = 0; i < collegeSituationList.size(); i++) {
                            //excel生成序号
                            collegeSituationList.get(i).setIndex(i + 1);
                        }
                        List<CollegeSituation> list = new ArrayList<>();
                        for (CollegeSituation enterprise : collegeSituationList) {
                            // 拆分字段的逗号分隔值
                            String[] activitiesName = enterprise.getActivitiesName().split(",");
                            String[] activitiesFrom = enterprise.getActivitiesFrom().split(",");
                            // 处理每个拆分后的数据项
                            int[] maxLen = {
                                    activitiesName.length,
                                    activitiesFrom.length,
                            };
                            int maxDataCount = max(maxLen);
                            for (int i = 0; i < maxDataCount; i++) {
                                CollegeSituation row = new CollegeSituation();
                                row.setIndex(enterprise.getIndex());
                                row.setSpaceName(enterprise.getSpaceName());
                                row.setActivitiesName(getSplitValue(activitiesName, i));
                                row.setActivitiesFrom(getSplitValue(activitiesFrom, i));
                                list.add(row);
                            }
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(), CollegeSituation.class).sheet("在孵企业在OTC高校板挂牌情况").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .doWrite(list);
                        response.flushBuffer();
                    }
                    break;
                case "22":
                    //引导指标13
                    //导出文件名称
                    String fileName_o = "引导指标十三";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_o).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<EnterprisesIntellectual> enterprisesIntellectualList = questionnaireDao.selectEnterprisesIntellectualListNew(qnYear, createId, id77, id78, id79, id80, id81);
                    if (enterprisesIntellectualList != null) {
                        for (int i = 0; i < enterprisesIntellectualList.size(); i++) {
                            //excel生成序号
                            enterprisesIntellectualList.get(i).setIndex(i + 1);
                        }
                        List<EnterprisesIntellectual> list = new ArrayList<>();
                        for (EnterprisesIntellectual enterprise : enterprisesIntellectualList) {
                            // 拆分字段的逗号分隔值
                            String[] enterpriseName = enterprise.getEnterpriseName().split(",");
                            String[] forTime = enterprise.getForTime().split(",");
                            String[] acquiredType = enterprise.getAcquiredType().split(",");
                            String[] serialNumber = enterprise.getSerialNumber().split(",");
                            String[] supportingMaterials = enterprise.getSupportingMaterials().split(",");
                            // 处理每个拆分后的数据项
                            int[] maxLen = {
                                    enterpriseName.length,
                                    forTime.length,
                                    acquiredType.length,
                                    serialNumber.length,
                                    supportingMaterials.length,
                            };
                            int maxDataCount = max(maxLen);
                            for (int i = 0; i < maxDataCount; i++) {
                                EnterprisesIntellectual row = new EnterprisesIntellectual();
                                row.setIndex(enterprise.getIndex());
                                row.setSpaceName(enterprise.getSpaceName());
                                row.setEnterpriseName(getSplitValue(enterpriseName, i));
                                row.setForTime(getSplitValue(forTime, i));
                                row.setAcquiredType(getSplitValue(acquiredType, i));
                                row.setSerialNumber(getSplitValue(serialNumber, i));
                                row.setSupportingMaterials(getSplitValue(supportingMaterials, i));
                                list.add(row);
                            }
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(), EnterprisesIntellectual.class).sheet("在孵企业新增知识产权").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .doWrite(list);
                        response.flushBuffer();
                    }
                    break;
                case "23":
                    //奖励指标1
                    //导出文件名称
                    String fileName_p = "奖励指标一";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_p).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<NationalCompetitionAwards> nationalCompetitionAwardsList = questionnaireDao.selectNationalCompetitionAwardsListNew(qnYear, createId, id82, id83, id84, id85, id86);
                    if (nationalCompetitionAwardsList != null) {
                        for (int i = 0; i < nationalCompetitionAwardsList.size(); i++) {
                            //excel生成序号
                            nationalCompetitionAwardsList.get(i).setIndex(i + 1);
                        }
                        List<NationalCompetitionAwards> list = new ArrayList<>();
                        for (NationalCompetitionAwards enterprise : nationalCompetitionAwardsList) {
                            // 拆分字段的逗号分隔值
                            String[] track = enterprise.getTrack().split(",");
                            String[] prizes = enterprise.getPrizes().split(",");
                            String[] winningTeam = enterprise.getWinningTeam().split(",");
                            String[] winningProject = enterprise.getWinningProject().split(",");
                            String[] isSupportingMaterials = enterprise.getIsSupportingMaterials().split(",");
                            // 处理每个拆分后的数据项
                            int[] maxLen = {
                                    track.length,
                                    prizes.length,
                                    winningTeam.length,
                                    winningProject.length,
                                    isSupportingMaterials.length,
                            };
                            int maxDataCount = max(maxLen);
                            for (int i = 0; i < maxDataCount; i++) {
                                NationalCompetitionAwards row = new NationalCompetitionAwards();
                                row.setIndex(enterprise.getIndex());
                                row.setSpaceName(enterprise.getSpaceName());
                                row.setTrack(getSplitValue(track, i));
                                row.setPrizes(getSplitValue(prizes, i));
                                row.setWinningTeam(getSplitValue(winningTeam, i));
                                row.setWinningProject(getSplitValue(winningProject, i));
                                row.setIsSupportingMaterials(getSplitValue(isSupportingMaterials, i));
                                list.add(row);
                            }
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(), NationalCompetitionAwards.class).sheet("获得“互联网+”大赛全国赛事奖项情况").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .doWrite(list);
                        response.flushBuffer();
                    }
                    break;
                case "24":
                    //奖励指标2
                    //导出文件名称
                    String fileName_n = "奖励指标二";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_n).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<EducationCommission> educationCommissionList = questionnaireDao.selectEducationCommissionListNew(qnYear, createId, id87, id88, id89, id90, id91, id92);
                    if (educationCommissionList != null) {
                        for (int i = 0; i < educationCommissionList.size(); i++) {
                            //excel生成序号
                            educationCommissionList.get(i).setIndex(i + 1);
                        }
                        List<EducationCommission> list = new ArrayList<>();
                        for (EducationCommission enterprise : educationCommissionList) {
                            // 拆分字段的逗号分隔值
                            String[] eventName = enterprise.getEventName().split(",");
                            String[] organizedCompetition = enterprise.getOrganizedCompetition().split(",");
                            String[] wonPrizes = enterprise.getWonPrizes().split(",");
                            String[] winningTeam = enterprise.getWinningTeam().split(",");
                            String[] winningProject = enterprise.getWinningProject().split(",");
                            String[] supportingMaterials = enterprise.getSupportingMaterials().split(",");
                            // 处理每个拆分后的数据项
                            int[] maxLen = {
                                    eventName.length,
                                    organizedCompetition.length,
                                    wonPrizes.length,
                                    winningTeam.length,
                                    winningProject.length,
                                    supportingMaterials.length,
                            };
                            int maxDataCount = max(maxLen);
                            for (int i = 0; i < maxDataCount; i++) {
                                EducationCommission row = new EducationCommission();
                                row.setIndex(enterprise.getIndex());
                                row.setSpaceName(enterprise.getSpaceName());
                                row.setEventName(getSplitValue(eventName, i));
                                row.setOrganizedCompetition(getSplitValue(organizedCompetition, i));
                                row.setWonPrizes(getSplitValue(wonPrizes, i));
                                row.setWinningTeam(getSplitValue(winningTeam, i));
                                row.setWinningProject(getSplitValue(winningProject, i));
                                row.setSupportingMaterials(getSplitValue(supportingMaterials, i));
                                list.add(row);
                            }
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(), EducationCommission.class).sheet("获得创客马拉松大赛及市教委组织的其他双创大赛奖项情况").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .doWrite(list);
                        response.flushBuffer();
                    }
                    break;
                case "25":
                    //奖励指标3
                    //导出文件名称
                    String fileName_m = "奖励指标三";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_m).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<EntrepreneurialProject> entrepreneurialProjectList = questionnaireDao.selectEntrepreneurialProjectListNew(qnYear, createId, id93, id94, id95, id96);
                    if (entrepreneurialProjectList != null) {
                        for (int i = 0; i < entrepreneurialProjectList.size(); i++) {
                            //excel生成序号
                            entrepreneurialProjectList.get(i).setIndex(i + 1);
                        }
                        List<EntrepreneurialProject> list = new ArrayList<>();
                        for (EntrepreneurialProject enterprise : entrepreneurialProjectList) {
                            // 拆分字段的逗号分隔值
                            String[] theYear = enterprise.getTheYear().split(",");
                            String[] projectName = enterprise.getProjectName().split(",");
                            String[] isWhetherProject = enterprise.getIsWhetherProject().split(",");
                            String[] isOutstandingProject = enterprise.getIsOutstandingProject().split(",");
                            // 处理每个拆分后的数据项
                            int[] maxLen = {
                                    theYear.length,
                                    projectName.length,
                                    isWhetherProject.length,
                                    isOutstandingProject.length,
                            };
                            int maxDataCount = max(maxLen);
                            for (int i = 0; i < maxDataCount; i++) {
                                EntrepreneurialProject row = new EntrepreneurialProject();
                                row.setIndex(enterprise.getIndex());
                                row.setSpaceName(enterprise.getSpaceName());
                                row.setTheYear(getSplitValue(theYear, i));
                                row.setProjectName(getSplitValue(projectName, i));
                                row.setIsWhetherProject(getSplitValue(isWhetherProject, i));
                                row.setIsOutstandingProject(getSplitValue(isOutstandingProject, i));
                                list.add(row);
                            }
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(), EntrepreneurialProject.class).sheet("入选天津市创业拔尖项目情况").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .doWrite(list);
                        response.flushBuffer();
                    }
                    break;
                case "26":
                    //奖励指标4-奖励指标5
                    //奖励指标3
                    //导出文件名称
                    String fileName_u = "奖励指标四、五";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_u).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<SpaceAndIncubation> spaceAndIncubationList = questionnaireDao.selectSpaceAndIncubationListNew(qnYear, createId, id97, id98);
                    if (spaceAndIncubationList != null) {
                        for (int i = 0; i < spaceAndIncubationList.size(); i++) {
                            //excel生成序号
                            spaceAndIncubationList.get(i).setIndex(i + 1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(), SpaceAndIncubation.class).sheet("是否为国家级备案众创空间").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .registerWriteHandler(new ExcelFillCellMergeStrategy(mergeRowIndex, mergeColumnIndex))
                                .doWrite(spaceAndIncubationList);
                        response.flushBuffer();
                    }
                    break;
                default:
                    break;
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    @Override
    public List<FormOptionByGroup> getFormOptions(int year, String createId) {
        // 根据年份查询问卷id
        Integer questionnaireId = questionnaireDao.queryQuestionsId(year);
        // 根据问卷uid 和创建人id 查询上报id
        Integer aId = questionnaireDao.queryReport(createId, Long.valueOf(questionnaireId));
        // 根据问卷id 查询组别列表
        List<FormGroup> formGroups = questionnaireDao.queryGroup(questionnaireId);
        //创建一个表单列表
        ArrayList<FormOptionByGroup> formOptionByGroups = new ArrayList<>();
        for (FormGroup formGroup : formGroups) {
            // 创建一个表单对象
            FormOptionByGroup formOptionByGroup = new FormOptionByGroup();
            BeanUtils.copyProperties(formGroup, formOptionByGroup);
            // 分割问题列表
            String[] questionIds = formGroup.getQuestionId().split(",");
            // 构建题目列表
            ArrayList<FormOptionsDto> formOptionsDtos = new ArrayList<>();
            for (String questionId : questionIds) {
                List<Questions> questions = questionnaireDao.queryQuestionsByQuestionnaireId(Integer.parseInt(questionId));
                // 创建选项列表
                List<Options> options;
                for (Questions question : questions) {
                    // 根据问题id查询选项列表
                    options = questionnaireDao.queryOptionsByQuestionId(question.getId());
                    // 根据选每一项id与aid 查询之前保存的内容
                    if (aId != null) {
                        for (Options option : options) {
                            String s = questionnaireDao.queryAnswersByIdBatch(option.getId().intValue(), aId, formGroup.getGroupId());
                            option.setFormContent(s);
                        }
                    }
                    // 构建题目
                    FormOptionsDto formOptionsDto = new FormOptionsDto();
                    BeanUtils.copyProperties(question, formOptionsDto);
                    formOptionsDto.setOptions(options);
                    formOptionsDtos.add(formOptionsDto);
                }
            }
            // 创建表单对象
            formOptionByGroup.setFormOptions(formOptionsDtos);
            formOptionByGroups.add(formOptionByGroup);
        }
        return formOptionByGroups;

    }

    @Override
    @Transactional
    public Map<String, Object> selectReport(ReportDto reportDto) {
        HashMap<String, Object> map = new HashMap<>();
        String createId = reportDto.getCreateId();
        Long questionnaireUuid = reportDto.getQuestionnaireUuid();
        List<AnswerDTO> answer = reportDto.getAnswer();
        // 查询是否有上报记录
        Integer aId = questionnaireDao.queryReport(createId, questionnaireUuid);
        if (aId != null) {
            // 如果状态为上报更新上报状态
            if (reportDto.getType() == 1) {
                questionnaireDao.updateReportStatus(aId);
            }
            Integer count = questionnaireDao.queryAnswer(aId);
            Integer answers;
            if (count != 0) {
                // 有上报记录 更新上报记录
                answers = questionnaireDao.updateAnswersByIdBatch(formFiltering(answer), aId);
            } else {
                // 根据id与每项插入值
                answers = questionnaireDao.insertAnswers(formFiltering(answer), aId);
            }
            if (answers > 0) {
                map.put("status", "success");
                map.put("total", answers);
                return map;
            }
        }
        return new HashMap<>();
    }

    @Override
    public boolean saveQuestionByGroup(SaveQuestionByGroup saveQuestionByGroup) {
//        String createId = saveQuestionByGroup.getCreateId();
//        Long questionnaireUuid = saveQuestionByGroup.getQuestionnaireUuid();
//        // 查询上报记录id
//        Integer aId = questionnaireDao.queryReport(createId, questionnaireUuid);
//        String questionIds = questionnaireDao.selectGroupById(saveQuestionByGroup.getGroupId());
//        String[] split = questionIds.split(",");
//        int questionId =0;
//        for (String s : split) {
//            questionId = questionId+ Integer.parseInt(s);
//        }
//        try {
//            for (String s : questionIds.split(",")) {
//                questionnaireDao.saveQuestionByGroup(questionId,
//                        aId, saveQuestionByGroup.getRemark(), saveQuestionByGroup.getStatus(),
//                        saveQuestionByGroup.getScore(), saveQuestionByGroup.getGroupId());
//            }
//        } catch (Exception e) {
//            return false;
//        }
//        return true;
//        根据uuid和createId查询上报信息
        Record recordPost = questionnaireDao.getRecord
                (saveQuestionByGroup.getQuestionnaireUuid(), saveQuestionByGroup.getCreateId());
        //根据上报ID查询是否为空
        boolean emptyReview = isEmptyReview(recordPost.getId());
        if(emptyReview) {
            //创建新审批对象
            //创建新增审批得列表
            List<Review> reviewList = new ArrayList<>();
            //根据UUid 查询groupId和QuestionId集合
            List<QuestionGroupDTO> questionGroups = questionnaireDao.getQuestionGroups
                    (saveQuestionByGroup.getQuestionnaireUuid());
            //分隔字符串问题ID求和为1个
            for (QuestionGroupDTO questionGroup : questionGroups) {
                Review reviewAdd = new Review();
                String[] split=  questionGroup.getQuestionId().split(",");
                long questionId = 0L;
                for (String s : split) {
                    questionId = questionId+ Long.parseLong(s);
                }
                reviewAdd.setApprovalStatus(-1);
                reviewAdd.setGroupId(questionGroup.getGroupId());
                reviewAdd.setQuestionsId(questionId);
                reviewAdd.setRecordId(recordPost.getId());
                reviewList.add(reviewAdd);
            }
            questionnaireDao.saveQuestionByReview(reviewList);
        }
        Review review = new Review();
        review.setRecordId(recordPost.getId());
        review.setGroupId(saveQuestionByGroup.getGroupId());
        review.setApprovalStatus(saveQuestionByGroup.getStatus());
        review.setScore(saveQuestionByGroup.getScore());
        review.setRemark(saveQuestionByGroup.getRemark());
        questionnaireDao.updateQuestionReview(review);
        return true;
    }


    /***
     *  为空返回true
     * @param recordId 上报ID
     * @return
     */
    @Override
    public boolean isEmptyReview(Long recordId) {
        List<Review> emptyReviewList = questionnaireDao.isEmptyReviewList(recordId);
        return emptyReviewList.isEmpty();
    }

    @Override
    public List<QuestionGroupDTO> getQuestionGroups(Long questionnaireUId) {
        return questionnaireDao.getQuestionGroups(questionnaireUId);
    }

    @Override
    public Record getRecord(Long questionnaireUuid, String createId) {
        return questionnaireDao.getRecord(questionnaireUuid,createId);
    }

    @Override
    public List<SaveQuestionDTO> queryReview(Long uid, String createId, int year) {
        // 查询上报记录id
//        try {
//            Integer aId = questionnaireDao.queryReport(createId, uid);
//            ArrayList<SaveQuestionByGroup> saveQuestionByGroups = new ArrayList<>();
//            for (FormGroup formGroup : questionnaireDao.queryGroup(Integer.parseInt(uid.toString()))) {
//                String questionsId = formGroup.getQuestionId();
//                int questionId = Integer.parseInt(questionsId.split(",")[0]);
//                SaveQuestionByGroup saveQuestionByGroup = new SaveQuestionByGroup();
//                Review review = questionnaireDao.selectReview(questionId, aId, formGroup.getGroupId());
//                if (review == null) {
//                    saveQuestionByGroups.add(null);
//                    continue;
//                }
//                saveQuestionByGroup.setGroupId(formGroup.getGroupId());
//                saveQuestionByGroup.setStatus(review.getApprovalStatus());
//                saveQuestionByGroup.setScore(review.getScore());
//                saveQuestionByGroup.setRemark(review.getRemark());
//                saveQuestionByGroups.add(saveQuestionByGroup);
//            }
//            return saveQuestionByGroups;
//        } catch (Exception e) {
//            return null;
//        }
        return questionnaireDao.queryReviewList(createId, uid);
    }

    @Override
    public boolean adminSubmit(Long uid, String createId, int year, int status) {
        Integer res = questionnaireDao.updateRecordStatus(uid, createId, year, status);
        return res != null;
    }


    public List<AnswerDTO> formFiltering(List<AnswerDTO> answerDTOS) {
        Map<Integer, AnswerDTO> map = new HashMap<>();
        ArrayList<String> jc3 = new ArrayList<>();
        ArrayList<String> jc6 = new ArrayList<>();

        for (AnswerDTO dto : answerDTOS) {

            Group group = questionnaireDao.selectGroup(dto.getGroupId());
            if (group.getGroupTitle().contains("基础指标3")) {
                jc3.add((String) dto.getValue());
            }

            if (group.getGroupTitle().contains("基础指标6")) {
                jc6.add((String) dto.getValue());
            }

            if (!map.containsKey(dto.getOptionId())) {
                map.put(dto.getOptionId(), dto);
            } else {
                if (map.get(dto.getOptionId()) != null) {
                    AnswerDTO answerDTO = map.get(dto.getOptionId());
                    dto.setValue(answerDTO.getValue());
                    dto.setOptionId(answerDTO.getOptionId());
                }
            }
        }
        // 按条件格式化jc3
        List<String> jc3s = spiltArrayJc3(jc3);
        List<String> jc6s = spiltArrayJc6(jc6);

        int jc3i = 0;
        int jc6i = 0;


        for (AnswerDTO dto : answerDTOS) {
            Group group = questionnaireDao.selectGroup(dto.getGroupId());
            if (jc3s.size() != 0) {
                if (group.getGroupTitle().contains("引导指标4") && jc3i <= jc3s.size()) {
                    dto.setValue(jc3s.get(jc3i));
                    jc3i++;
                }
            } else {
                if (group.getGroupTitle().contains("引导指标4")) {
                    dto.setValue(null);
                }
            }
            if (jc6s.size() != 0) {
                if (group.getGroupTitle().contains("引导指标7") && jc6i <= jc6s.size()) {
                    dto.setValue(jc6s.get(jc6i));
                    jc6i++;
                }
            } else {
                if (group.getGroupTitle().contains("引导指标7")) {
                    dto.setValue(null);
                }
            }
        }
        return answerDTOS;
    }

    public List<String> spiltArrayJc3(ArrayList<String> list) {
        if (list.size() == 0) {
            return new ArrayList<>();
        }
        List<String[]> rows = new ArrayList<>();

        // 按照,分割
        for (String str : list) {
            if (str == null|| str.trim().equals(",")) {
                rows.add(new String[0]);
                continue;
            }
            rows.add(str.split(","));
        }

        int maxCol = 0;
        for (String[] row : rows) {
            maxCol = Math.max(maxCol, row.length);
        }

        // 转换数组
        String[][] result = new String[maxCol][rows.size()];
        for (int i = 0; i < rows.size(); i++) {
            String[] row = rows.get(i);
            for (int j = 0; j < row.length; j++) {
                result[j][i] = row[j];
            }
        }

        // 判断条件
        List<String[]> resultList = new ArrayList<>();
        for (String[] row : result) {
            if ("是".equals(row[row.length - 1])) {
                resultList.add(row);
            }
        }

        // 还原数组
        String[][] resultArray = new String[resultList.size()][];
        resultList.toArray(resultArray);

        List<String> str = new ArrayList<>();

        if (resultArray.length == 0) {
            return new ArrayList<>();
        }
        for (String[] row : resultArray) {
            for (int j = 0; j < row.length; j++) {
                if (row[j] == null) {
                    row[j] = ""; // 将null替换为""
                }
            }
        }

        for (int i = 0; i < resultArray[0].length; i++) {
            StringBuilder s = new StringBuilder();
            for (String[] strings : resultArray) {
                s.append(strings[i]).append(",");
            }
            str.add(String.valueOf(s).substring(0, String.valueOf(s).length() - 1));
        }

        return str;
    }

    public List<String> spiltArrayJc6(ArrayList<String> list) {
        if (list.size() == 0) {
            return new ArrayList<>();
        }
        List<String[]> rows = new ArrayList<>();

        // 按照,分割
        for (String str : list) {
            if (str == null|| str.trim().equals(",")) {
                rows.add(new String[0]);
                continue;
            }
            rows.add(str.split(","));
        }

        int maxCol = 0;
        for (String[] row : rows) {
            maxCol = Math.max(maxCol, row.length);
        }

        // 转换数组
        String[][] result = new String[maxCol][rows.size()];
        for (int i = 0; i < rows.size(); i++) {
            String[] row = rows.get(i);
            for (int j = 0; j < row.length; j++) {
                result[j][i] = row[j];
            }
        }

        // 判断条件
        List<String[]> resultList = new ArrayList<>();
        for (String[] row : result) {

            if ("是".equals(row[15]) || "是".equals(row[11])) {
                resultList.add(row);
            }
        }

        // 还原数组
        String[][] resultArray = new String[resultList.size()][];
        resultList.toArray(resultArray);

        if (resultArray.length == 0) {
            return new ArrayList<>();
        }
        for (String[] row : resultArray) {
            for (int j = 0; j < row.length; j++) {
                if (row[j] == null) {
                    row[j] = ""; // 将null替换为""
                }
            }
        }

        List<String> str = new ArrayList<>();
        for (int i = 0; i < resultArray[0].length; i++) {
            StringBuilder s = new StringBuilder();
            for (String[] strings : resultArray) {
                s.append(strings[i]).append(",");
            }
            str.add(String.valueOf(s).substring(0, String.valueOf(s).length() - 1));
        }

        return str;
    }


    // 辅助方法，获取拆分数据的索引值，限制在有效范围内
    private String getSplitValue(String[] dataArray, int index) {
        if (index >= 0 && index < dataArray.length) {
            return dataArray[index];
        } else {
            return ""; // 或者根据需求返回默认值
        }
    }
}
